(* ::Package:: *)

(*:Package Version: 1.06 *)

(*:Version History: 1.01 (2013.01.14 - 2013.05.01)
                    1.02 (2013.05.02 - 2014.03.12)
                    1.03 (2014.03.17 - 2015.11.02)Blasius
                    1.04 (2015.11.03 - 2016.11.13)LaneEmden
                    1.05 (2016.11.14 - 2022.12.10)Lorenz
                    1.06 (2022.12.11 - 20XX.XX.XX)HyperLemniscate, Squigonometric *)

(*:Copyright: Copyright 2013.01-2022.12, Souichiro Ikebe *)

(*:Author: Souichiro Ikebe *)

(*:Name: SpecialFunctions`NDSolveComplexDomain` *)

(*:Title: NDSolve, VanDerPol, Duffing, LotkaVolterra, Blasius, LaneEmden, Lorenz *)

(*:Keywords: VanDerPol, VanDerPolPrime, VanDerPolPhase, Duffing, DuffingPrime, 
             DuffingPhase, NonForcedDuffing, NonForcedDuffingPrime, 
             NonForcedDuffingPhase, DuffingVanDerPol, DuffingVanDerPolPrime, 
             DuffingVanDerPolPhase, LotkaVolterraX, LotkaVolterraY, 
             Blasius, BlasiusPrime, BlasiusPrimePrime, 
             Polking, PolkingPrime, PolkingPhase, BrusselatorX, BrusselatorY, 
             NLDampedOscillation, NLDampedOscillationPrime, 
             NLDampedOscillationPhase, Elastica, 
             HyperLemniscateS, HyperLemniscateSPrime, HyperOmega, PerHLOddGreater3, 
             HyperLemniscateSRadialCut, HyperLemniscateSPrimeRadialCut, 
             HyperLemniscateS6, HyperLemniscateS8, 
             SquigonometricC, SquigonometricS, 
             SquigonometricCAnalytic, SquigonometricSAnalytic, 
             LaneEmden, LaneEmdenPrime, 
             LorenzX, LorenzY, LorenzZ *)

(*:Summary:
\:3000\:3000This package will add a method to solved in the complex domain 
\:3000\:3000the solution of differential equations using the NDSolve, a feature 
\:3000\:3000built into the Mathematica.
*)

(**********************************************************************************)





BeginPackage["SpecialFunctions`NDSolveComplexDomain`"]





VanDerPol::usage =
"VanDerPol[mu,z,{w1,w2}] gives solutions of the differential equation of 
 Van-der-Pol : y''[z]-mu*(1-y[z]^2)*y'[z]+y[z]=0; 
 with y[0]=w1; y'[0]=w2."

VanDerPolPrime::usage =
"VanDerPolPrime[mu,z,{w1,w2}] gives derivative of the Van-der-Pol function 
 VanDerPol[mu,z,{w1,w2}] at z."

VanDerPolPhase::usage =
"VanDerPolPhase[mu,z,{w1,w2}] gives set of the solutions of the 
 differential equation of Van-der-Pol and its derivatives at z."

Duffing::usage =
"Duffing[{a,b,c,d},z,{w1,w2}] gives solutions of the differential 
 equation of Duffing : y''[z]+a*y'[z]+b*y[z]^3+c*y[z]-d*Cos[z]=0; 
 with y[0]=w1; y'[0]=w2."

DuffingPrime::usage =
"DuffingPrime[{a,b,c,d},z,{w1,w2}] gives derivative of the Duffing function 
 Duffing[{a,b,c,d},z,{w1,w2}] at z."

DuffingPhase::usage =
"DuffingPhase[{a,b,c,d},z,{w1,w2}] gives set of the solutions of the 
 differential equation of Duffing and its derivatives at z."

NonForcedDuffing::usage =
"NonForcedDuffing[{a,b,c,d},z,{w1,w2}] gives solutions of the Non-forced-Duffing 
 differential equation : y''[z]+a*y'[z]+b*y[z]^3+c*y[z]-d=0; 
 with y[0]=w1; y'[0]=w2."

NonForcedDuffingPrime::usage =
"NonForcedDuffingPrime[{a,b,c,d},z,{w1,w2}] gives derivative of the 
 Nonforced-Duffing function NonForcedDuffing[{a,b,c,d},z,{w1,w2}] at z."

NonForcedDuffingPhase::usage =
"NonForcedDuffingPhase[{a,b,c,d},z,{w1,w2}] gives set of the solutions 
 of the Nonforced-Duffing differential equation and its derivatives at z."

DuffingVanDerPol::usage =
"DuffingVanDerPol[{mu,nu,d,k},z,{w1,w2}] gives solutions of the Duffing
 Van-der-Pol differential equation : 
 y''[z]-mu*(1-y[z]^2)*y'[z]+nu*y[z]-d*Sin[k*z]=0; 
 with y[0]=w1; y'[0]=w2."

DuffingVanDerPolPrime::usage =
"DuffingVanDerPolPrime[{mu,nu,d,k},z,{w1,w2}] gives derivative of the 
 Duffing Van-der-Pol function DuffingVanDerPol[{mu,nu,d,k},z,{w1,w2}] at z."

DuffingVanDerPolPhase::usage =
"DuffingVanDerPolPhase[{mu,nu,d,k},z,{w1,w2}] gives set of the solutions 
 of the Duffing Van-der-Pol differential equation and its derivatives at z."

LotkaVolterraX::usage =
"LotkaVolterraX[{{a0,a1,a2},{b0,b1,b2}},z,{x0,y0}] gives solutions X[z] 
 of the Lotka-Volterra differential equation : 
 X'[z]=(a0+a1*Y[z]+a2*X[z])*X[z]; and Y'[z]=(b0+b1*X[z]+b2*Y[z])*Y[z]; 
 with X[0]=x0; Y[0]=y0."

LotkaVolterraY::usage =
"LotkaVolterraY[{{a0,a1,a2},{b0,b1,b2}},z,{x0,y0}] gives solutions Y[z] 
 of the Lotka-Volterra differential equation : 
 X'[z]=(a0+a1*Y[z]+a2*X[z])*X[z]; and Y'[z]=(b0+b1*X[z]+b2*Y[z])*Y[z]; 
 with X[0]=x0; Y[0]=y0."

Blasius::usage =
"Blasius[z] gives solutions of the differential equation of Blasius : 
 2*y'''[z]+y[z]*y''[z]=0; with y[0]=0; y'[0]=0; y'[Infinity]=1.
 Blasius[z,{w0,w1,w2}] gives solutions of the differential equation of 
 Blasius of generalized initial values case : 
 2*y'''[z]+y[z]*y''[z]=0; with y[0]=w0; y'[0]=w1; y''[0]=w2."

BlasiusPrime::usage =
"BlasiusPrime[z] gives derivative of the Blasius function Blasius[z] at z.
 BlasiusPrime[z,{w0,w1,w2}] gives derivative of the generalized Blasius 
 function Blasius[z,{w0,w1,w2}] at z."

BlasiusPrimePrime::usage =
"BlasiusPrimePrime[z] gives second derivative of the Blasius function 
 Blasius[z] at z.
 BlasiusPrimePrime[z,{w0,w1,w2}] gives second derivative of the 
 generalized Blasius function Blasius[z,{w0,w1,w2}] at z."

Polking::usage =
"Polking[z,{w1,w2}] gives solutions of the differential equation of Polking :
 y''[z]-y'[z]^2+y[z]=0; with y[0]=w1; y'[0]=w2."

PolkingPrime::usage =
"PolkingPrime[z,{w1,w2}] gives derivative of the Polking function :
 Polking[z,{w1,w2}] at z."

PolkingPhase::usage =
"PolkingPhase[z,{w1,w2}] gives set of the solutions of the differential 
 equation of Polking and its derivatives at z."

BrusselatorX::usage =
"BrusselatorX[{a,b},z,{x0,y0}] gives solutions X[z] of the Brusselator
 (Brussel school) differential equation : 
 X'[z]=a-(b+1)*X[z]+X[z]^2*y[z]; and Y'[z]=b*X[z]-X[z]^2*Y[z]; 
 with X[0]=x0; Y[0]=y0."

BrusselatorY::usage =
"BrusselatorY[{a,b},z,{x0,y0}] gives solutions Y[z] of the Brusselator
 (Brussel school) differential equation : 
 X'[z]=a-(b+1)*X[z]+X[z]^2*y[z]; and Y'[z]=b*X[z]-X[z]^2*Y[z]; 
 with X[0]=x0; Y[0]=y0."

NLDampedOscillation::usage =
"NLDampedOscillation[{a,b},z,{w1,w2}] gives solutions of the Nonlinear
 damped oscillators differential equation : y''[z]+a*y'[z]+b*Sin[y[z]]=0;
 with y[0]=w1; y'[0]=w2."

NLDampedOscillationPrime::usage =
"NLDampedOscillationPrime[{a,b},z,{w1,w2}] gives derivative of the 
 Nonlinear damped oscillators function 
 NLDampedOscillation[{a,b},z,{w1,w2}] at z."

NLDampedOscillationPhase::usage =
"NLDampedOscillationPhase[{a,b},z,{w1,w2}] gives set of the solutions of the 
 Nonlinear damped oscillators differential equation and its derivatives at z."

Elastica::usage =
"Elastica[z,k] gives Elastica functions. (It is also inverse function of 
 the elliptic integrals of the second kind on the Elastica.)"

HyperLemniscateS::usage =
"HyperLemniscateS[n,z] gives Hyper lemniscate functions of order n."

HyperLemniscateSPrime::usage =
"HyperLemniscateSPrime[n,z] gives derivative of Hyper lemniscate functions of order n."

HyperOmega::usage =
"HyperOmega[n] gives Hyper omega constants with quarter period of 
 Hyper lemniscate function."

PerHLOddGreater3::usage =
"PerHLOddGreater3[n] gives period of Hyper lemniscate functions of odd order n>3."

HyperLemniscateSRadialCut::usage =
"HyperLemniscateSRadialCut[n,z] gives Hyper lemniscate functions of order n, 
 with radial branch cut type."

HyperLemniscateSPrimeRadialCut::usage =
"HyperLemniscateSPrimeRadialCut[n,z] gives derivative of Hyper lemniscate functions 
 of order n, with radial branch cut type."

HyperLemniscateS6::usage =
"HyperLemniscateS6[z] gives Hyper lemniscate functions of order 6. 
 (Legacy code.)"

HyperLemniscateS8::usage =
"HyperLemniscateS8[z] gives Hyper lemniscate functions of order 8. 
 (This function employs a strict branch cutting line than HyperLemniscateS[8,z].)"

SquigonometricC::usage =
"SquigonometricC[n,z] gives Squigonometric cosine functions of order n."

SquigonometricS::usage =
"SquigonometricS[n,z] gives Squigonometric sine functions of order n."

SquircleK::usage =
"SquircleK[n] gives Squircle K-constants with quarter period of 
 Squigonometric function."

SquigonometricCAnalytic::usage =
"SquigonometricCAnalytic[n,z] gives Squigonometric cosine functions of 
 analytic continuation."

SquigonometricSAnalytic::usage =
"SquigonometricSAnalytic[n,z] gives Squigonometric sine functions of 
 analytic continuation."

LaneEmden::usage =
"LaneEmden[n,z] gives solutions of the differential equation of 
 Lane-Emden : y''[z]+2/z*y'[z]+y[z]^n=0; 
 with y[0]=1; y'[0]=0, and n is non negative integers or half odd numbers."

LaneEmdenPrime::usage =
"LaneEmdenPrime[n,z] gives derivative of the Lane-Emden function 
 LaneEmden[n,z] at z."

LorenzX::usage =
"LorenzX[s,b,r,{t,tMax},{x0,y0,z0}] gives solutions X[t] of the Lorenz 
 differential equation : 
 x'[t]=s*(y[t]-x[t]); y'[t]=x[t]*(r-z[t])-y[t]; z'[t]=x[t]*y[t]-b*z[t];
 with X[0]=x0; Y[0]=y0; Z[0]=z0; and tMax is maximum value of interval 
 [0,tMax] for solving interpolating function."

LorenzY::usage =
"LorenzY[s,b,r,{t,tMax},{x0,y0,z0}] gives solutions Y[t] of the Lorenz 
 differential equation : 
 x'[t]=s*(y[t]-x[t]); y'[t]=x[t]*(r-z[t])-y[t]; z'[t]=x[t]*y[t]-b*z[t];
 with X[0]=x0; Y[0]=y0; Z[0]=z0; and tMax is maximum value of interval 
 [0,tMax] for solving interpolating function."

LorenzZ::usage =
"LorenzZ[s,b,r,{t,tMax},{x0,y0,z0}] gives solutions Z[t] of the Lorenz 
 differential equation : 
 x'[t]=s*(y[t]-x[t]); y'[t]=x[t]*(r-z[t])-y[t]; z'[t]=x[t]*y[t]-b*z[t];
 with X[0]=x0; Y[0]=y0; Z[0]=z0; and tMax is maximum value of interval 
 [0,tMax] for solving interpolating function."



Begin["SpecialFunctions`NDSolveComplexDomain`Private`"]





(**********************************************************************************)
(*                            VanDerPol[mu,z,{w1,w2}]                             *)
(**********************************************************************************)

realVanDerPol[mu_,z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]-mu*(1-f[x]^2)*f'[x]+f[x]==0,
         f[0]==w1,f'[0]==w2},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

VanDerPol[mu_,z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realVanDerPol[mu,Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-mu*I*(1-f[x]^2)*f'[x]-f[x]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                          VanDerPolPrime[mu,z,{w1,w2}]                          *)
(**********************************************************************************)

VanDerPolPrime[mu_,z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realVanDerPol[mu,Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-mu*I*(1-f[x]^2)*f'[x]-f[x]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    -I*f'[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                          VanDerPolPhase[mu,z,{w1,w2}]                          *)
(**********************************************************************************)

VanDerPolPhase[mu_,z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realVanDerPol[mu,Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-mu*I*(1-f[x]^2)*f'[x]-f[x]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                          Duffing[{a,b,c,d},z,{w1,w2}]                          *)
(**********************************************************************************)

Duffing[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Tan[arctanDuffing[{a,b,c,d},z,{ArcTan[w1],w2/(1+w1^2)}]]/;
  (Precision[z]<Infinity)

realArcTanDuffing[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]+2*Tan[f[x]]*(f'[x])^2+a*f'[x]+b*Tan[f[x]]*Sin[f[x]]^2+
           c*Sin[f[x]]*Cos[f[x]]-d*Cos[x]*Cos[f[x]]^2==0,
         f[0]==w1,f'[0]==w2},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

arctanDuffing[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realArcTanDuffing[{a,b,c,d},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]+2*Tan[f[x]]*(f'[x])^2+a*I*f'[x]-b*Tan[f[x]]*Sin[f[x]]^2-
           c*Sin[f[x]]*Cos[f[x]]+d*Cos[Re[z]+x*I]*Cos[f[x]]^2==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]];



(**********************************************************************************)
(*                       DuffingPrime[{a,b,c,d},z,{w1,w2}]                        *)
(**********************************************************************************)

DuffingPrime[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  arctanDuffingPrime[{a,b,c,d},z,{ArcTan[w1],w2/(1+w1^2)}]*
  Sec[arctanDuffing[{a,b,c,d},z,{ArcTan[w1],w2/(1+w1^2)}]]^2/;
  (Precision[z]<Infinity)

arctanDuffingPrime[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realArcTanDuffing[{a,b,c,d},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]+2*Tan[f[x]]*(f'[x])^2+a*I*f'[x]-b*Tan[f[x]]*Sin[f[x]]^2-
           c*Sin[f[x]]*Cos[f[x]]+d*Cos[Re[z]+x*I]*Cos[f[x]]^2==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    -I*f'[Im[z]]/.sol[[1]]];



(**********************************************************************************)
(*                       DuffingPhase[{a,b,c,d},z,{w1,w2}]                        *)
(**********************************************************************************)

DuffingPhase[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Module[{atdp},
    atdp=arctanDuffingPhase[{a,b,c,d},z,{ArcTan[w1],w2/(1+w1^2)}];
    {Tan[atdp[[1]]],atdp[[2]]*Sec[atdp[[1]]]^2}]/;
  (Precision[z]<Infinity)

arctanDuffingPhase[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realArcTanDuffing[{a,b,c,d},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]+2*Tan[f[x]]*(f'[x])^2+a*I*f'[x]-b*Tan[f[x]]*Sin[f[x]]^2-
           c*Sin[f[x]]*Cos[f[x]]+d*Cos[Re[z]+x*I]*Cos[f[x]]^2==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]];



(**********************************************************************************)
(*                     NonForcedDuffing[{a,b,c,d},z,{w1,w2}]                      *)
(**********************************************************************************)

realNFDuffing[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]+a*f'[x]+b*f[x]^3+c*f[x]-d==0,
          f[0]==w1,f'[0]==w2},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

NonForcedDuffing[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Block[{$MinPrecision=15},
  Module[{init,sol,f,x,zp,ap,bp,cp,dp,w1p,w2p,prec=15},
    zp=SetPrecision[z,prec];
    ap=SetPrecision[a,prec];
    bp=SetPrecision[b,prec];
    cp=SetPrecision[c,prec];
    dp=SetPrecision[d,prec];
    w1p=SetPrecision[w1,prec];
    w2p=SetPrecision[w2,prec];
    init=realNFDuffing[{ap,bp,cp,dp},Re[zp],{w1p,w2p}];
    sol=NDSolve[{f''[x]+ap*I*f'[x]-bp*f[x]^3-cp*f[x]+dp==0,
        f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[zp]},
        AccuracyGoal->15,PrecisionGoal->15,WorkingPrecision->15,
        MaxSteps->Infinity,Method->"Extrapolation"];
    f[Im[z]]/.sol[[1]]]]/;
    (Precision[z]<Infinity)



(**********************************************************************************)
(*                   NonForcedDuffingPrime[{a,b,c,d},z,{w1,w2}]                   *)
(**********************************************************************************)

NonForcedDuffingPrime[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Block[{$MinPrecision=15},
  Module[{init,sol,f,x,zp,ap,bp,cp,dp,w1p,w2p,prec=15},
    zp=SetPrecision[z,prec];
    ap=SetPrecision[a,prec];
    bp=SetPrecision[b,prec];
    cp=SetPrecision[c,prec];
    dp=SetPrecision[d,prec];
    w1p=SetPrecision[w1,prec];
    w2p=SetPrecision[w2,prec];
    init=realNFDuffing[{ap,bp,cp,dp},Re[zp],{w1p,w2p}];
    sol=NDSolve[{f''[x]+ap*I*f'[x]-bp*f[x]^3-cp*f[x]+dp==0,
        f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[zp]},
        AccuracyGoal->15,PrecisionGoal->15,WorkingPrecision->15,
        MaxSteps->Infinity,Method->"Extrapolation"];
    -I*f'[Im[z]]/.sol[[1]]]]/;
    (Precision[z]<Infinity)



(**********************************************************************************)
(*                   NonForcedDuffingPhase[{a,b,c,d},z,{w1,w2}]                   *)
(**********************************************************************************)

NonForcedDuffingPhase[{a_,b_,c_,d_},z_,{w1_,w2_}]:=
  Block[{$MinPrecision=15},
  Module[{init,sol,f,x,zp,ap,bp,cp,dp,w1p,w2p,prec=15},
    zp=SetPrecision[z,prec];
    ap=SetPrecision[a,prec];
    bp=SetPrecision[b,prec];
    cp=SetPrecision[c,prec];
    dp=SetPrecision[d,prec];
    w1p=SetPrecision[w1,prec];
    w2p=SetPrecision[w2,prec];
    init=realNFDuffing[{ap,bp,cp,dp},Re[zp],{w1p,w2p}];
    sol=NDSolve[{f''[x]+ap*I*f'[x]-bp*f[x]^3-cp*f[x]+dp==0,
        f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[zp]},
        AccuracyGoal->15,PrecisionGoal->15,WorkingPrecision->15,
        MaxSteps->Infinity,Method->"Extrapolation"];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]]]/;
    (Precision[z]<Infinity)



(**********************************************************************************)
(*                    DuffingVanDerPol[{mu,nu,d,k},z,{w1,w2}]                     *)
(**********************************************************************************)

realDufVDP[{mu_,nu_,d_,k_},z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]-mu*(1-f[x]^2)*f'[x]+nu*f[x]-d*Sin[k x]==0,
         f[0]==w1,f'[0]==w2},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

DuffingVanDerPol[{mu_,nu_,d_,k_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realDufVDP[{mu,nu,d,k},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-mu*I*(1-f[x]^2)*f'[x]-nu*f[x]+d*Sin[k (Re[z]+x*I)]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                  DuffingVanDerPolPrime[{mu,nu,d,k},z,{w1,w2}]                  *)
(**********************************************************************************)

DuffingVanDerPolPrime[{mu_,nu_,d_,k_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realDufVDP[{mu,nu,d,k},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-mu*I*(1-f[x]^2)*f'[x]-nu*f[x]+d*Sin[k (Re[z]+x*I)]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    -I*f'[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                  DuffingVanDerPolPhase[{mu,nu,d,k},z,{w1,w2}]                  *)
(**********************************************************************************)

DuffingVanDerPolPhase[{mu_,nu_,d_,k_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realDufVDP[{mu,nu,d,k},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-mu*I*(1-f[x]^2)*f'[x]-nu*f[x]+d*Sin[k (Re[z]+x*I)]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                         LotkaVolterraX, LotkaVolterraY                         *)
(**********************************************************************************)

LotkaVolterraX[{{a0_,a1_,a2_},{b0_,b1_,b2_}},z_,{x0_,y0_}]:=
  LotkVolt[{1+b2/a1,2*a0*b2/a1-b0,2*a2*b2/a1-a2-b1,
    a0*b0-a0^2*b2/a1,a0*b1+a2*b0-2*a0*a2*b2/a1,
    a2*b1-a2^2*b2/a1},z,{x0,(a0+a1*y0+a2*x0)*x0}]/;
   (Precision[z]<Infinity)

LotkaVolterraY[{{a0_,a1_,a2_},{b0_,b1_,b2_}},z_,{x0_,y0_}]:=
  LotkVolt[{1+a2/b1,2*b0*a2/b1-a0,2*b2*a2/b1-b2-a1,
    b0*a0-b0^2*a2/b1,b0*a1+b2*a0-2*b0*b2*a2/b1,
    b2*a1-b2^2*a2/b1},z,{y0,(b0+b1*x0+b2*y0)*y0}]/;
   (Precision[z]<Infinity)

realLotkVolt[{a_,b_,c_,d_,e_,g_},z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]-a/f[x]*f'[x]^2+(b+c*f[x])*f'[x]+d*f[x]+e*f[x]^2+g*f[x]^3==0,
         f[0]==w1,f'[0]==w2},f,{x,z},MaxStepSize->0.01];
    {f[z],f'[z]}/.sol[[1]]];

LotkVolt[{a_,b_,c_,d_,e_,g_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realLotkVolt[{a,b,c,d,e,g},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-a/f[x]*f'[x]^2+I*(b+c*f[x])*f'[x]-d*f[x]-e*f[x]^2-g*f[x]^3==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]];



(**********************************************************************************)
(*               Blasius[z], BlasiusPrime[z], BlasiusPrimePrime[z]                *)
(**********************************************************************************)

(* Blasius constant Kappa *)
BlasiusKappa=0.33205733621519629893718006201;

(* Blasius function *)
Blasius[z_]:=
  Module[{omeg=(-1+Sqrt[3] I)/2},
  Which[-Pi/3<=Arg[z]<=Pi/3 || N[Im[z]]===0.,origBlasius[z],
    -Pi<Arg[z]<-Pi/3,omeg*origBlasius[omeg*z],
    Pi/3<Arg[z]<Pi,origBlasius[z/omeg]/omeg]]/;
  (Precision[z]<Infinity)

realOrBlasius[z_]:=
  Module[{sol,f,x},
    sol=NDSolve[{2*f'''[x]+f[x]*f''[x]==0,
      f[0]==0,f'[0]==0,f''[0]==BlasiusKappa},f,{x,z}];
    {f[z],f'[z],f''[z]}/.sol[[1]]];

origBlasius[z_]:=
  Module[{init,sol,f,x},
    init=realOrBlasius[Re[z]];
    sol=NDSolve[{2 I*f'''[x]-f[x]*f''[x]==0,
      f[0]==init[[1]],f'[0]==I*init[[2]],f''[0]==-init[[3]]},
      f,{x,Im[z]},MaxStepSize->0.002];
    f[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)

(* Original region of Pade approximant *)
regionPadeBlasius[z_]:=
  If[Abs[2 (z/6.4)^2.33/(1+(z/6.4)^2.33)]<2 && Re[z]>8,
    True,False];

(* A-coefficients of power series of Blasius function *)
coefBlasiusA[0]:=1;

coefBlasiusA[1]:=1;

coefBlasiusA[n_/;(IntegerQ[n] && n>=2)]:=
  coefBlasiusA[n]=
  Sum[Binomial[3 n-1,3 r]*coefBlasiusA[r]*coefBlasiusA[n-r-1],{r,0,n-1,1}];

(* Derivative of Blasius function *)
BlasiusPrime[z_]:=
  Module[{omeg=(-1+Sqrt[3] I)/2},
  Which[-Pi/3<=Arg[z]<=Pi/3 || N[Im[z]]===0.,origBlasiusPrime[z],
    -Pi<Arg[z]<-Pi/3,origBlasiusPrime[omeg*z]/omeg,
    Pi/3<Arg[z]<Pi,omeg*origBlasiusPrime[z/omeg]]]/;
  (Precision[z]<Infinity)

origBlasiusPrime[z_]:=
  Module[{init,sol,f,x},
    init=realOrBlasius[Re[z]];
    sol=NDSolve[{2 I*f'''[x]-f[x]*f''[x]==0,
      f[0]==init[[1]],f'[0]==I*init[[2]],f''[0]==-init[[3]]},
      f,{x,Im[z]},MaxStepSize->0.002];
    -I*f'[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity && regionPadeBlasius[z]===False)

origBlasiusPrime[z_]:=
  N[Module[{max=300,powerL},
    powerL=Table[SetPrecision[z,600]^j,{j,1,max,1}];
    (coefBlasP1[0]+padeBlasP1CoefA[max].powerL)/
    (1+padeBlasP1CoefB[max].powerL)]]/;
   (Precision[z]<Infinity && regionPadeBlasius[z]===True)

coefBlasP1[n_/;(IntegerQ[n] && Mod[n,3]===1)]:=
  coefBlasiusA[(n-1)/3]*(-1/2)^((n-1)/3)*
  SetPrecision[BlasiusKappa,600]^((n+2)/3)/(n!);

coefBlasP1[n_/;(IntegerQ[n] && Mod[n,3]=!=1)]:=0;

padeBlasP1MatrixA[v_Integer?Positive]:=
  Table[If[j-k<0,0,coefBlasP1[j-k]],{j,0,v,1},{k,0,v,1}];

padeBlasP1MatrixB[v_Integer?Positive]:=
  Table[coefBlasP1[v+j-k],{j,0,v-1,1},{k,0,v-1,1}];

padeBlasP1CoefA[v_Integer?Positive]:=
  padeBlasP1CoefA[v]=
  Rest[Flatten[padeBlasP1MatrixA[v].Join[{1},padeBlasP1CoefB[v]]]];

padeBlasP1CoefB[v_Integer?Positive]:=
  padeBlasP1CoefB[v]=
  LinearSolve[padeBlasP1MatrixB[v],Table[-coefBlasP1[v+j],{j,1,v,1}]];

(* Second order derivative of Blasius function *)
BlasiusPrimePrime[z_]:=
  Module[{omeg=(-1+Sqrt[3] I)/2},
  Which[-Pi/3<=Arg[z]<=Pi/3 || N[Im[z]]===0.,origBlasiusPrimePrime[z],
    -Pi<Arg[z]<-Pi/3,origBlasiusPrimePrime[omeg*z],
    Pi/3<Arg[z]<Pi,origBlasiusPrimePrime[z/omeg]]]/;
  (Precision[z]<Infinity)

origBlasiusPrimePrime[z_]:=
  Module[{init,sol,f,x},
    init=realOrBlasius[Re[z]];
    sol=NDSolve[{2 I*f'''[x]-f[x]*f''[x]==0,
      f[0]==init[[1]],f'[0]==I*init[[2]],f''[0]==-init[[3]]},
      f,{x,Im[z]},MaxStepSize->0.002];
    -f''[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity && regionPadeBlasius[z]===False)

origBlasiusPrimePrime[z_]:=
  N[Module[{max=300,powerL},
  powerL=Table[SetPrecision[z,600]^j,{j,1,max,1}];
    (coefBlasP2[0]+padeBlasP2CoefA[max].powerL)/
    (1+padeBlasP2CoefB[max].powerL)]]/;
   (Precision[z]<Infinity && regionPadeBlasius[z]===True)

coefBlasP2[n_/;(IntegerQ[n] && Mod[n,3]===0)]:=
  coefBlasiusA[n/3]*(-1/2)^(n/3)*
  SetPrecision[BlasiusKappa,600]^(n/3+1)/(n!);

coefBlasP2[n_/;(IntegerQ[n] && Mod[n,3]=!=0)]:=0;

padeBlasP2MatrixA[v_Integer?Positive]:=
  Table[If[j-k<0,0,coefBlasP2[j-k]],{j,0,v,1},{k,0,v,1}];

padeBlasP2MatrixB[v_Integer?Positive]:=
  Table[coefBlasP2[v+j-k],{j,0,v-1,1},{k,0,v-1,1}];

padeBlasP2CoefA[v_Integer?Positive]:=
  padeBlasP2CoefA[v]=
  Rest[Flatten[padeBlasP2MatrixA[v].Join[{1},padeBlasP2CoefB[v]]]];

padeBlasP2CoefB[v_Integer?Positive]:=
  padeBlasP2CoefB[v]=
  LinearSolve[padeBlasP2MatrixB[v],Table[-coefBlasP2[v+j],{j,1,v,1}]];



(**********************************************************************************)
(*               Blasius[z,{w0,w1,w2}], BlasiusPrime[z,{w0,w1,w2}],               *)
(*               BlasiusPrimePrime[z,{w0,w1,w2}]                                  *)
(**********************************************************************************)

Blasius[z_,{w0_,w1_,w2_}]:=
  Module[{theta,sol,f,x},
    theta=If[z==0,0,Arg[z]];
    sol=NDSolve[{2*Exp[-3 I*theta]*f'''[x]+Exp[-2 I*theta]*f''[x]*f[x]==0,
      f[0]==w0,f'[0]==Exp[I*theta]*w1,f''[0]==Exp[2 I*theta]*w2},f,{x,Abs[z]},
      MaxStepSize->0.002];
    f[Abs[z]]/.sol[[1]]]/;
  (Precision[z]<Infinity)

BlasiusPrime[z_,{w0_,w1_,w2_}]:=
  Module[{theta,sol,f,x},
    theta=If[z==0,0,Arg[z]];
    sol=NDSolve[{2*Exp[-3 I*theta]*f'''[x]+Exp[-2 I*theta]*f''[x]*f[x]==0,
      f[0]==w0,f'[0]==Exp[I*theta]*w1,f''[0]==Exp[2 I*theta]*w2},f,{x,Abs[z]},
      MaxStepSize->0.002];
    Exp[-I*theta]*f'[Abs[z]]/.sol[[1]]]/;
  (Precision[z]<Infinity)

BlasiusPrimePrime[z_,{w0_,w1_,w2_}]:=
  Module[{theta,sol,f,x},
    theta=If[z==0,0,Arg[z]];
    sol=NDSolve[{2*Exp[-3 I*theta]*f'''[x]+Exp[-2 I*theta]*f''[x]*f[x]==0,
      f[0]==w0,f'[0]==Exp[I*theta]*w1,f''[0]==Exp[2 I*theta]*w2},f,{x,Abs[z]},
      MaxStepSize->0.002];
    Exp[-2 I*theta]*f''[Abs[z]]/.sol[[1]]]/;
  (Precision[z]<Infinity)



(**********************************************************************************)
(*                               Polking[z,{w1,w2}]                               *)
(**********************************************************************************)

realPolking[z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]-(f'[x])^2+f[x]==0,
         f[0]==w1,f'[0]==w2},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

Polking[z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realPolking[Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-(f'[x])^2-f[x]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                            PolkingPrime[z,{w1,w2}]                             *)
(**********************************************************************************)

PolkingPrime[z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realPolking[Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-(f'[x])^2-f[x]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    -I*f'[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                            PolkingPhase[z,{w1,w2}]                             *)
(**********************************************************************************)

PolkingPhase[z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realPolking[Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-(f'[x])^2-f[x]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*          BrusselatorX[{a,b},z,{x0,y0}], BrusselatorY[{a,b},z,{x0,y0}]          *)
(**********************************************************************************)

BrusselatorX[{a_,b_},z_,{x0_,y0_}]:=
  brusselX[{a,b},z,{x0,a-(b+1)*x0+x0^2*y0}]/;
  (Precision[z]<Infinity)

BrusselatorY[{a_,b_},z_,{x0_,y0_}]:=
  Module[{brx},brx=BrusselatorX[{a,b},z,{x0,y0}];
  (brusselXPrime[{a,b},z,{x0,a-(b+1)*x0+x0^2*y0}]-a)/brx^2+(b+1)/brx]/;
  (Precision[z]<Infinity)

realBrusselX[{a_,b_},z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]-2/f[x]*(f'[x])^2+(f[x]^2+2 a/f[x]-b-1)*f'[x]-a*f[x]^2+f[x]^3==0,
         f[0]==w1,f'[0]==w2},f,{x,z},MaxStepSize->0.01];
    {f[z],f'[z]}/.sol[[1]]];

brusselX[{a_,b_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realBrusselX[{a,b},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-2/f[x]*(f'[x])^2+I*(f[x]^2+2 a/f[x]-b-1)*f'[x]+a*f[x]^2-f[x]^3==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]];

brusselXPrime[{a_,b_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realBrusselX[{a,b},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]-2/f[x]*(f'[x])^2+I*(f[x]^2+2 a/f[x]-b-1)*f'[x]+a*f[x]^2-f[x]^3==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    -I*f'[Im[z]]/.sol[[1]]];



(**********************************************************************************)
(*                      NLDampedOscillation[{a,b},z,{w1,w2}]                      *)
(**********************************************************************************)

realNLDOsc[{a_,b_},z_,{w1_,w2_}]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]+a*f'[x]+b*Sin[f[x]]==0,
         f[0]==w1,f'[0]==w2},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

NLDampedOscillation[{a_,b_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realNLDOsc[{a,b},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]+a*I*f'[x]-b*Sin[f[x]]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                   NLDampedOscillationPrime[{a,b},z,{w1,w2}]                    *)
(**********************************************************************************)

NLDampedOscillationPrime[{a_,b_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realNLDOsc[{a,b},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]+a*I*f'[x]-b*Sin[f[x]]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    -I*f'[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                   NLDampedOscillationPhase[{a,b},z,{w1,w2}]                    *)
(**********************************************************************************)

NLDampedOscillationPhase[{a_,b_},z_,{w1_,w2_}]:=
  Module[{init,sol,f,x},
    init=realNLDOsc[{a,b},Re[z],{w1,w2}];
    sol=NDSolve[{f''[x]+a*I*f'[x]-b*Sin[f[x]]==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]]/;
   (Precision[z]<Infinity)



(**********************************************************************************)
(*                                 Elastica[z,k]                                  *)
(**********************************************************************************)

realElastica[z_,k_]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]+4*(1+k)^2*f[x]/(1-k+2*k*f[x]^2)^3==0,
         f[0]==0,f'[0]==2/(1-k)},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];

Elastica[z_,k_]:=
  Module[{init,sol,f,x},
    init=realElastica[Re[z],k];
    sol=NDSolve[{f''[x]-4*(1+k)^2*f[x]/(1-k+2*k*f[x]^2)^3==0,
         f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    f[Im[z]]/.sol[[1]]]/;
   (Precision[z]<Infinity && N[k]=!=1.)



(**********************************************************************************)
(*               HyperLemniscateS[n,z], HyperLemniscateSPrime[n,z]                *)
(**********************************************************************************)

(********** Common code : Hyper omega constant **********)

HyperOmega[n_]:=
  Sqrt[Pi]*Gamma[1+1/n]/Gamma[1/2+1/n];

(********** n === 1 **********)

HyperLemniscateS[n_,z_]:=
  Module[{iN=Round[n]},
    1-(1-z/2)^2]/;
  (Chop[Abs[n-1]]===0 && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{iN=Round[n]},
    1-z/2]/;
  (Chop[Abs[n-1]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 2 **********)

HyperLemniscateS[n_,z_]:=
  Module[{iN=Round[n]},
    Sin[z]]/;
  (Chop[Abs[n-2]]===0 && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{iN=Round[n]},
    Cos[z]]/;
  (Chop[Abs[n-2]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 3 **********)

HyperLemniscateS[n_,z_]:=
  Module[{iN=Round[n],val},
    val=4^(1/3)*WeierstrassP[I*(4^(-1/3)*z+Gamma[1/3]^3/(2*Sqrt[3]*Pi)),{0,1}];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (Chop[Abs[n-3]]===0 && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{iN=Round[n],val},
    val=I*WeierstrassPPrime[I*(4^(-1/3)*z+Gamma[1/3]^3/(2*Sqrt[3]*Pi)),{0,1}];
    If[Abs[Im[z]]>0,val,Re[val]]]/;
  (Chop[Abs[n-3]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 4 **********)

HyperLemniscateS[n_,z_]:=
  Module[{iN=Round[n]},
    JacobiSD[Sqrt[2]*z,1/2]/Sqrt[2]]/;
  (Chop[Abs[n-4]]===0 && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{iN=Round[n]},
    JacobiCD[Sqrt[2]*z,1/2]*JacobiND[Sqrt[2]*z,1/2]]/;
  (Chop[Abs[n-4]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 6 **********)

HyperLemniscateS[n_,z_]:=
  Module[{h=2*HyperOmega[6],sgn,a,m},
    sgn=If[Mod[Re[z]+h,2*h]-h<0,-1,1];
    a=2*3^(1/4);m=(2-Sqrt[3])/4;
    sgn*Sqrt[1-JacobiCN[a*z,m]]/Sqrt[1+Sqrt[3]-(1-Sqrt[3])*JacobiCN[a*z,m]]]/;
  (Chop[Abs[n-6]]===0 && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{h=2*HyperOmega[6],sgn,a,m,rF},
    sgn=If[Mod[Re[z]+h,2*h]-h<0,-1,1];
    a=2*3^(1/4);m=(2-Sqrt[3])/4;
    rF=1+Sqrt[3]-(1-Sqrt[3])*JacobiCN[a*z,m];
    sgn*Sqrt[3]*a*JacobiDN[a*z,m]*JacobiSN[a z,m]/rF/Sqrt[rF]/Sqrt[1-JacobiCN[a*z,m]]]/;
  (Chop[Abs[n-6]]===0 && NumericQ[n] && NumericQ[z])

(********** n === Odd || n =!= Integer **********)

HyperLemniscateS[n_,z_]:=
  Module[{iN,epsilon=If[Re[n]<10.5,1/20,1/100],val},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    val=If[Im[z]>=0,
      epsCompHypLemnS[iN,z-epsilon*I,epsilon],
      epsCompHypLemnS[iN,z+epsilon*I,-epsilon]];
    If[realIntervalHypLemnQ[iN,z] && Not[Abs[Im[z]]>0],Re[val],val]]/;
  (Chop[Abs[n-1]]=!=0 && Chop[Abs[n-3]]=!=0 && Not[Chop[Im[n]]===0 && 
   Chop[n/2-Floor[(n+1)/2]]===0] && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{iN,epsilon=If[Re[n]<10.5,1/20,1/100],val},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    val=If[Im[z]>=0,
      epsCompHypLemnSPrime[iN,z-epsilon*I,epsilon],
      epsCompHypLemnSPrime[iN,z+epsilon*I,-epsilon]];
    If[realIntervalHypLemnQ[iN,z] && Not[Abs[Im[z]]>0],Re[val],val]]/;
  (Chop[Abs[n-1]]=!=0 && Chop[Abs[n-3]]=!=0 && Not[Chop[Im[n]]===0 && 
   Chop[n/2-Floor[(n+1)/2]]===0] && NumericQ[n] && NumericQ[z])

realIntervalHypLemnQ[n_,z_]:=
  Module[{ho=HyperOmega[n],c=Cos[Pi/n],p=PerHLOddGreater3[n]},
    Which[OddQ[n] && n>3,
      -ho/c<=(Mod[Re[z]+p/2,p]-p/2)<=ho*(2+1/c),
      True,0<=Re[z]<=ho]];

PerHLOddGreater3[n_]:=
  Module[{m},
    m[k_]:=Which[k===1,6,k===Floor[n/2],4,True,8];
    HyperOmega[n]/Cos[Pi/n]*Sum[m[k]*(Cos[(2*k-1)*Pi/n]-Cos[(2*k+1)*Pi/n]),{k,1,Floor[n/2]}]];

epsCompHypLemnS[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=epsRealHypLemnS[n,Re[z],epsilon];
    sol=NDSolve[{x'[t]==I*y[t],y'[t]==-I*n/2*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    x[Im[z]]/.sol[[1]]];

epsCompHypLemnSPrime[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=epsRealHypLemnS[n,Re[z],epsilon];
    sol=NDSolve[{x'[t]==I*y[t],y'[t]==-I*n/2*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    y[Im[z]]/.sol[[1]]];

epsRealHypLemnS[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=compHypLemnS[n,epsilon*I];
    sol=NDSolve[{x'[t]==y[t],y'[t]==-n/2*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];

compHypLemnS[n_,z_]:=
  Module[{init,sol,x,y,t},
    init=realHypLemnS[n,Re[z]];
    sol=NDSolve[{x'[t]==I*y[t],y'[t]==-I*n/2*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[Im[z]],y[Im[z]]}/.sol[[1]]];

realHypLemnS[n_,z_]:=
  Module[{sol,x,y,t},
    sol=NDSolve[{x'[t]==y[t],y'[t]==-n/2*x[t]^(n-1),
      x[0]==0,y[0]==1},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];

(********** n === Even **********)

HyperLemniscateS[n_,z_]:=
  Module[{oN=Round[n],om2,perZ,val},
    om2=2*HyperOmega[oN];
    perZ=Mod[Re[z]+om2,2 om2]-om2+I*Im[z];
    val=compHypLemnSEven[oN,perZ][[1]];
    If[Abs[Im[n]]>0 || Abs[Im[z]]>0,val,Re[val]]]/;
  (Chop[Abs[n-2]]=!=0 && Chop[Abs[n-4]]=!=0 && Chop[Abs[n-6]]=!=0 && 
   Chop[Im[n]]===0 && Chop[n/2-Floor[(n+1)/2]]===0 && NumericQ[n] && NumericQ[z])

HyperLemniscateSPrime[n_,z_]:=
  Module[{oN=Round[n],om2,perZ,val},
    om2=2*HyperOmega[oN];
    perZ=Mod[Re[z]+om2,2 om2]-om2+I*Im[z];
    val=compHypLemnSEven[oN,perZ][[2]];
    If[Abs[Im[n]]>0 || Abs[Im[z]]>0,val,Re[val]]]/;
  (Chop[Abs[n-2]]=!=0 && Chop[Abs[n-4]]=!=0 && Chop[Abs[n-6]]=!=0 && 
   Chop[Im[n]]===0 && Chop[n/2-Floor[(n+1)/2]]===0 && NumericQ[n] && NumericQ[z])

compHypLemnSEven[n_,z_]:=
  Module[{init,sol,f,x},
    init=realHypLemnSEven[n,Re[z]];
    sol=NDSolve[{f''[x]-n/2*f[x]^(n-1)==0,
      f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]}];
    {f[Im[z]],-I*f'[Im[z]]}/.sol[[1]]];

realHypLemnSEven[n_,z_]:=
  Module[{sol,f,x},
    sol=NDSolve[{f''[x]+n/2*f[x]^(n-1)==0,
      f[0]==0,f'[0]==1},f,{x,z}];
    {f[z],f'[z]}/.sol[[1]]];



(**********************************************************************************)
(*      HyperLemniscateSRadialCut[n,z], HyperLemniscateSPrimeRadialCut[n,z]       *)
(**********************************************************************************)

HyperLemniscateSRadialCut[n_,z_]:=
  Module[{iN,theta,sol,x,y,t},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    theta=If[z==0,0,Arg[z]];
    sol=NDSolve[{x'[t]==Exp[I*theta]*y[t],y'[t]==-iN/2*Exp[I*theta]*x[t]^(iN-1),
      x[0]==0,y[0]==1},{x,y},{t,Abs[z]},
      MaxStepSize->0.002,Method->"StiffnessSwitching"];
    x[Abs[z]]/.sol[[1]]]/;
  (NumericQ[n] && NumericQ[z])

HyperLemniscateSPrimeRadialCut[n_,z_]:=
  Module[{iN,theta,sol,x,y,t},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    theta=If[z==0,0,Arg[z]];
    sol=NDSolve[{x'[t]==Exp[I*theta]*y[t],y'[t]==-iN/2*Exp[I*theta]*x[t]^(iN-1),
      x[0]==0,y[0]==1},{x,y},{t,Abs[z]},
      MaxStepSize->0.002,Method->"StiffnessSwitching"];
    y[Abs[z]]/.sol[[1]]]/;
  (NumericQ[n] && NumericQ[z])



(**********************************************************************************)
(*                       HyperLemniscateS6[z] (Legacy code)                       *)
(**********************************************************************************)

HyperLemniscateS6[z_]:=
  Module[{per6=N[Sqrt[Pi]*Gamma[7/6]/Gamma[2/3]]},
    If[Re[z]>per6,-HyperLemniscateS6[z-2*per6],
    If[Re[z]<-per6,-HyperLemniscateS6[z+2*per6],s6Unit[z]]]]/;
   (Precision[z]<Infinity)

s6Unit[z_]:=
  Module[{per6=N[Sqrt[Pi]*Gamma[7/6]/Gamma[2/3]]},
    Which[0<=Re[z]<=per6,s6Unit1[z],-per6<=Re[z]<0,s6Unit2[z]]];

s6Unit1[z_]:=
  Module[{per6=N[Sqrt[Pi]*Gamma[7/6]/Gamma[2/3]]},
    If[Abs[z]<=2/Sqrt[3]*per6,HyperLemniscateS[6,z],
    If[Abs[z]>2/Sqrt[3]*per6 && per6/Sqrt[3]<Im[z]<=Sqrt[3]*per6,
      -HyperLemniscateS[6,z-per6 (1+Sqrt[3] I)],
    If[Abs[z]>2/Sqrt[3]*per6 && -per6*Sqrt[3]<=Im[z]<-per6/Sqrt[3],
      -HyperLemniscateS[6,z-per6 (1-Sqrt[3] I)],
    If[Im[z]>per6*Sqrt[3],
      s6Unit1[z-2 I*per6*Sqrt[3]],s6Unit1[z+2 I*per6*Sqrt[3]]]]]]];

s6Unit2[z_]:=
  Module[{per6=N[Sqrt[Pi]*Gamma[7/6]/Gamma[2/3]]},
    If[Abs[z]<=2/Sqrt[3]*per6,HyperLemniscateS[6,z],
    If[Abs[z]>2/Sqrt[3]*per6 && per6/Sqrt[3]<Im[z]<=Sqrt[3]*per6,
      -HyperLemniscateS[6,z+per6 (1-Sqrt[3] I)],
    If[Abs[z]>2/Sqrt[3]*per6 && -per6*Sqrt[3]<=Im[z]<-per6/Sqrt[3],
      -HyperLemniscateS[6,z+per6 (1+Sqrt[3] I)],
    If[Im[z]>per6*Sqrt[3],
      s6Unit2[z-2 I*per6*Sqrt[3]],s6Unit2[z+2 I*per6*Sqrt[3]]]]]]];



(**********************************************************************************)
(*                              HyperLemniscateS8[z]                              *)
(**********************************************************************************)

HyperLemniscateS8[z_]:=
  Module[{per8=N[Sqrt[Pi]*Gamma[9/8]/Gamma[5/8]]},
    If[Re[z]>per8,-HyperLemniscateS8[z-2*per8],
    If[Re[z]<-per8,-HyperLemniscateS8[z+2*per8],s8Unit[z]]]]/;
   (Precision[z]<Infinity)

s8Unit[z_]:=
  Module[{per8=N[Sqrt[Pi]*Gamma[9/8]/Gamma[5/8]]},
    Which[Abs[Re[z]]<=(Sqrt[2]-1)*per8,s8Unit1[z],
      (Sqrt[2]-1)*per8<Re[z]<=per8,s8Unit2[z],
      -per8<=Re[z]<(1-Sqrt[2])*per8,s8Unit3[z]]];

s8Unit1[z_]:=
  Module[{per8=N[Sqrt[Pi]*Gamma[9/8]/Gamma[5/8]]},
    If[Abs[z]<=per8/Cos[Pi/8],HyperLemniscateS[8,z],
    If[Abs[z]>per8/Cos[Pi/8] && Im[z]>per8,
      -s8Unit1[z-2 I*per8],-s8Unit1[z+2 I*per8]]]];

s8Unit2[z_]:=
  Module[{per8=N[Sqrt[Pi]*Gamma[9/8]/Gamma[5/8]]},
    If[Abs[z]<=per8/Cos[Pi/8],HyperLemniscateS[8,z],
    If[Abs[z]>per8/Cos[Pi/8] && (Sqrt[2]-1)*per8<Im[z]<=Sqrt[2]*per8,
      -HyperLemniscateS[8,z-per8*Sqrt[2]*(1+I)],
    If[Abs[z]>per8/Cos[Pi/8] && -Sqrt[2]*per8<=Im[z]<-(Sqrt[2]-1)*per8,
      -HyperLemniscateS[8,z-per8*Sqrt[2]*(1-I)],
    If[Im[z]>Sqrt[2]*per8,
      s8Unit2[z-2 I*per8*Sqrt[2]],s8Unit2[z+2 I*per8*Sqrt[2]]]]]]];

s8Unit3[z_]:=
  Module[{per8=N[Sqrt[Pi]*Gamma[9/8]/Gamma[5/8]]},
    If[Abs[z]<=per8/Cos[Pi/8],HyperLemniscateS[8,z],
    If[Abs[z]>per8/Cos[Pi/8] && (Sqrt[2]-1)*per8<Im[z]<=Sqrt[2]*per8,
      -HyperLemniscateS[8,z+per8*Sqrt[2]*(1-I)],
    If[Abs[z]>per8/Cos[Pi/8] && -Sqrt[2]*per8<=Im[z]<-(Sqrt[2]-1)*per8,
      -HyperLemniscateS[8,z+per8*Sqrt[2]*(1+I)],
    If[Im[z]>Sqrt[2]*per8,
      s8Unit3[z-2 I*per8*Sqrt[2]],s8Unit3[z+2 I*per8*Sqrt[2]]]]]]];



(**********************************************************************************)
(*                   SquigonometricC[n,z], SquigonometricS[n,z]                   *)
(**********************************************************************************)

(********** Common code : Quarter period K[n] **********)

SquircleK[n_]:=
  Sqrt[Pi]*2^(1-2/n)*Gamma[1+1/n]/Gamma[1/2+1/n];

(********** n === 2 **********)

SquigonometricC[n_,z_]:=
  Cos[z]/;
  (Chop[Abs[n-2]]===0 && NumericQ[n] && NumericQ[z])

SquigonometricS[n_,z_]:=
  Sin[z]/;
  (Chop[Abs[n-2]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 4 **********)

SquigonometricC[n_,z_]:=
  Module[{sl,cl},
    sl=JacobiSD[z,1/2]/Sqrt[2];
    cl=JacobiCN[z,1/2];
    cl*Sqrt[1+sl^2]/Sqrt[sl^2+cl^2]]/;
  (Chop[Abs[n-4]]===0 && NumericQ[n] && NumericQ[z])

SquigonometricS[n_,z_]:=
  Module[{sl,cl},
    sl=JacobiSD[z,1/2]/Sqrt[2];
    cl=JacobiCN[z,1/2];
    sl*Sqrt[1+cl^2]/Sqrt[sl^2+cl^2]]/;
  (Chop[Abs[n-4]]===0 && NumericQ[n] && NumericQ[z])

(********** n =!= 2 && n =!= 4 **********)

SquigonometricC[n_,z_]:=
  Module[{iN,k,sgnC,conj,perZ,val},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    k=SquircleK[iN];
    sgnC=If[2*k-Mod[Re[z]+k,4*k]<0,-1,1];
    conj=If[Mod[Re[z],2*k]-k<0,1,-1];
    perZ=Abs[Mod[Re[z]+k,2*k]-k]+conj*I*Im[z];
    val=sgnC*unitSquigonometricC[iN,perZ];
    If[Abs[Im[n]]>0 || Abs[Im[z]]>0,val,Re[val]]]/;
  (Chop[Abs[n-2]]=!=0 && Chop[Abs[n-4]]=!=0 && NumericQ[n] && NumericQ[z])

SquigonometricS[n_,z_]:=
  Module[{iN,k,sgnS,conj,perZ,val},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    k=SquircleK[iN];
    sgnS=If[Mod[Re[z]+2*k,4*k]-2*k<0,-1,1];
    conj=If[Mod[Re[z],2*k]-k<0,1,-1];
    perZ=Abs[Mod[Re[z]+k,2*k]-k]+conj*I*Im[z];
    val=sgnS*unitSquigonometricS[iN,perZ];
    If[Abs[Im[n]]>0 || Abs[Im[z]]>0,val,Re[val]]]/;
  (Chop[Abs[n-2]]=!=0 && Chop[Abs[n-4]]=!=0 && NumericQ[n] && NumericQ[z])

unitSquigonometricC[n_,z_]:=
  Module[{init,sol,x,y,t},
    init=realSquigonometric[n,Re[z]];
    sol=NDSolve[{x'[t]==-I*y[t]^(n-1),y'[t]==I*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01];
    x[Im[z]]/.sol[[1]]];

unitSquigonometricS[n_,z_]:=
  Module[{init,sol,x,y,t},
    init=realSquigonometric[n,Re[z]];
    sol=NDSolve[{x'[t]==-I*y[t]^(n-1),y'[t]==I*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01];
    y[Im[z]]/.sol[[1]]];

realSquigonometric[n_,z_]:=
  Module[{sol,x,y,t,k=SquircleK[n]},
    sol=NDSolve[{x'[t]==-y[t]^(n-1),y'[t]==x[t]^(n-1),
      x[k/2]==2^(-1/n),y[k/2]==2^(-1/n)},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];



(**********************************************************************************)
(*           SquigonometricCAnalytic[n,z], SquigonometricSAnalytic[n,z]           *)
(**********************************************************************************)

(********** n === 1 **********)

SquigonometricCAnalytic[n_,z_]:=
  1-z/;
  (Chop[Abs[n-1]]===0 && NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  z/;
  (Chop[Abs[n-1]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 2 **********)

SquigonometricCAnalytic[n_,z_]:=
  Cos[z]/;
  (Chop[Abs[n-2]]===0 && NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  Sin[z]/;
  (Chop[Abs[n-2]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 3 **********)

SquigonometricCAnalytic[n_,z_]:=
  (3*WeierstrassPPrime[z,{0,1/27}]+1)/(3*WeierstrassPPrime[z,{0,1/27}]-1)/;
  (Chop[Abs[n-3]]===0 && NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  6*WeierstrassP[z,{0,1/27}]/(1-3*WeierstrassPPrime[z,{0,1/27}])/;
  (Chop[Abs[n-3]]===0 && NumericQ[n] && NumericQ[z])

(********** n === 4 **********)

SquigonometricCAnalytic[n_,z_]:=
  Module[{sl,cl},
    sl=JacobiSD[z,1/2]/Sqrt[2];
    cl=JacobiCN[z,1/2];
    cl*Sqrt[1+sl^2]/Sqrt[sl^2+cl^2]]/;
  (Chop[Abs[n-4]]===0 && NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  Module[{sl,cl},
    sl=JacobiSD[z,1/2]/Sqrt[2];
    cl=JacobiCN[z,1/2];
    sl*Sqrt[1+cl^2]/Sqrt[sl^2+cl^2]]/;
  (Chop[Abs[n-4]]===0 && NumericQ[n] && NumericQ[z])

(********** n =!= 1,2,3,4 && n =!= 1/2,3/2,5/2,... **********)

SquigonometricCAnalytic[n_,z_]:=
  If[0<=Re[z]<=SquircleK[n],Re[realSquig[n,z][[1]]]]/;
  (Abs[n]<1/3 && Not[Abs[Im[z]]>0] && Chop[Abs[n-1]]=!=0 && Chop[Abs[n-2]]=!=0 && 
   Chop[Abs[n-3]]=!=0 && Chop[Abs[n-4]]=!=0 && NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  If[0<=Re[z]<=SquircleK[n],Re[realSquig[n,z][[2]]]]/;
  (Abs[n]<1/3 && Not[Abs[Im[z]]>0] && Chop[Abs[n-1]]=!=0 && Chop[Abs[n-2]]=!=0 && 
   Chop[Abs[n-3]]=!=0 && Chop[Abs[n-4]]=!=0 && NumericQ[n] && NumericQ[z])

SquigonometricCAnalytic[n_,z_]:=
  Module[{iN,epsilon=1/20,val},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    val=If[Im[z]>=0,
      epsCompSquigC[iN,z-epsilon*I,epsilon],
      epsCompSquigC[iN,z+epsilon*I,-epsilon]];
    If[realIntervalSquigQ[iN,z] && Not[Abs[Im[z]]>0],Re[val],val]]/;
  (Not[Abs[n]<1/3 && Not[Abs[Im[z]]>0]] && Chop[Abs[n-1]]=!=0 && Chop[Abs[n-2]]=!=0 && 
   Chop[Abs[n-3]]=!=0 && Chop[Abs[n-4]]=!=0 && 
   Not[Chop[Im[n]]===0 && Chop[n-1/2-Floor[n]]===0] && NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  Module[{iN,epsilon=1/20,val},
    iN=If[Chop[Im[n]]===0 && Chop[n-Floor[n+1/2]]===0,Round[n],n];
    val=If[Im[z]>=0,
      epsCompSquigS[iN,z-epsilon*I,epsilon],
      epsCompSquigS[iN,z+epsilon*I,-epsilon]];
    If[realIntervalSquigQ[iN,z] && Not[Abs[Im[z]]>0],Re[val],val]]/;
  (Not[Abs[n]<1/3 && Not[Abs[Im[z]]>0]] && Chop[Abs[n-1]]=!=0 && Chop[Abs[n-2]]=!=0 && 
   Chop[Abs[n-3]]=!=0 && Chop[Abs[n-4]]=!=0 && 
   Not[Chop[Im[n]]===0 && Chop[n-1/2-Floor[n]]===0] && NumericQ[n] && NumericQ[z])

realIntervalSquigQ[n_,z_]:=
  Module[{k=SquircleK[n],s=Sec[Pi/n]/2,m=2*Cos[Pi/n]*(1+Cos[Pi/n])},
    Which[OddQ[n] && n>3,
      -k*s<=(Mod[Re[z]+k*m,2*k*m]-k*m)<=k*(1+s),
      EvenQ[n] || OddQ[n] && 1<=n<=3,
      Abs[Re[z]]>=0,
      True,0<=Re[z]<=k]];

epsCompSquigC[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=epsRealSquig[n,Re[z],epsilon];
    sol=NDSolve[{x'[t]==-I*y[t]^(n-1),y'[t]==I*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01];
    x[Im[z]]/.sol[[1]]];

epsCompSquigS[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=epsRealSquig[n,Re[z],epsilon];
    sol=NDSolve[{x'[t]==-I*y[t]^(n-1),y'[t]==I*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01];
    y[Im[z]]/.sol[[1]]];

epsRealSquig[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=compSquig[n,epsilon*I];
    sol=NDSolve[{x'[t]==-y[t]^(n-1),y'[t]==x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];

compSquig[n_,z_]:=
  Module[{init,sol,x,y,t},
    init=realSquig[n,Re[z]];
    sol=NDSolve[{x'[t]==-I*y[t]^(n-1),y'[t]==I*x[t]^(n-1),
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[Im[z]],y[Im[z]]}/.sol[[1]]];

realSquig[n_,z_]:=
  Module[{sol,x,y,t,k=SquircleK[n]},
    sol=NDSolve[{x'[t]==-y[t]^(n-1),y'[t]==x[t]^(n-1),
      x[k/2]==2^(-1/n),y[k/2]==2^(-1/n)},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];

(********** n === 1/2,3/2,5/2,... **********)

SquigonometricCAnalytic[n_,z_]:=
  Module[{val,epsilon=0.01},
    val=If[Im[z]>=0,
      epsCompSquigCHalf[Round[2 n],z/2-epsilon*I,epsilon]^2,
      epsCompSquigCHalf[Round[2 n],z/2+epsilon*I,-epsilon]^2];
    If[0<=Re[z]<=SquircleK[n] && Not[Abs[Im[z]]>0],Re[val],val]]/;
  (Chop[Im[n]]===0 && Chop[n-1/2-Floor[n]]===0 && 
   NumericQ[n] && NumericQ[z])

SquigonometricSAnalytic[n_,z_]:=
  Module[{val,epsilon=0.01},
    val=If[Im[z]>=0,
      epsCompSquigSHalf[Round[2 n],z/2-epsilon*I,epsilon]^2,
      epsCompSquigSHalf[Round[2 n],z/2+epsilon*I,-epsilon]^2];
    If[0<=Re[z]<=SquircleK[n] && Not[Abs[Im[z]]>0],Re[val],val]]/;
  (Chop[Im[n]]===0 && Chop[n-1/2-Floor[n]]===0 && 
   NumericQ[n] && NumericQ[z])

epsCompSquigCHalf[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=epsRealSquigHalf[n,Re[z],epsilon];
    sol=NDSolve[{x'[t]*x[t]+I*y[t]^(n-2)==0,y'[t]*y[t]-I*x[t]^(n-2)==0,
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      Method->"StiffnessSwitching"];
    x[Im[z]]/.sol[[1]]];

epsCompSquigSHalf[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t},
    init=epsRealSquigHalf[n,Re[z],epsilon];
    sol=NDSolve[{x'[t]*x[t]+I*y[t]^(n-2)==0,y'[t]*y[t]-I*x[t]^(n-2)==0,
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    y[Im[z]]/.sol[[1]]];

epsRealSquigHalf[n_,z_,epsilon_]:=
  Module[{init,sol,x,y,t,k=SquircleK[n/2]},
    init=compSquigHalf[n,k/4+epsilon*I];
    sol=NDSolve[{x'[t]*x[t]+y[t]^(n-2)==0,y'[t]*y[t]-x[t]^(n-2)==0,
      x[k/4]==init[[1]],y[k/4]==init[[2]]},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];

compSquigHalf[n_,z_]:=
  Module[{init,sol,x,y,t},
    init=realSquigHalf[n,Re[z]];
    sol=NDSolve[{x'[t]*x[t]+I*y[t]^(n-2)==0,y'[t]*y[t]-I*x[t]^(n-2)==0,
      x[0]==init[[1]],y[0]==init[[2]]},{x,y},{t,Im[z]},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[Im[z]],y[Im[z]]}/.sol[[1]]];

realSquigHalf[n_,z_]:=
  Module[{sol,x,y,t,k=SquircleK[n/2]},
    sol=NDSolve[{x'[t]*x[t]+y[t]^(n-2)==0,y'[t]*y[t]-x[t]^(n-2)==0,
      x[k/4]==2^(-1/n),y[k/4]==2^(-1/n)},{x,y},{t,z},
      MaxStepSize->0.01,Method->"StiffnessSwitching"];
    {x[z],y[z]}/.sol[[1]]];



(**********************************************************************************)
(*                      LaneEmden[n,z], LaneEmdenPrime[n,z]                       *)
(**********************************************************************************)

(************  LaneEmden[0, z], LaneEmdenPrime[0, z]  **************)

LaneEmden[0.,z_]:=LaneEmden[0,z];

LaneEmden[0,z_]:=1-z^2/6;

LaneEmdenPrime[0.,z_]:=LaneEmdenPrime[0,z];

LaneEmdenPrime[0,z_]:=-z/3;

(************  LaneEmden[1, z], LaneEmdenPrime[1, z]  **************)

LaneEmden[1.,z_]:=LaneEmden[1,z];

LaneEmden[1,z_]:=Sinc[z];

LaneEmdenPrime[1.,z_]:=LaneEmdenPrime[1,z];

LaneEmdenPrime[1,z_]:=
  If[Abs[z]>10^-3,
    (Cos[z]-Sinc[z])/z,
    Sum[(-1)^n*(2 n)/((2 n+1)!)*z^(2 n-1),{n,1,6}]];

(************************  LaneEmden[2, z]  ************************)

LaneEmden[2.,z_]:=LaneEmden[2,z];

LaneEmden[2,z_]:=smallLaneEmden[2,z]/;(Abs[z]<=10^-3)

LaneEmden[2,z_]:=
  LaneEmden[2,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=4},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==0.04884014997594444,f'[0]==-0.15040965958043956*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (Abs[z]>10^-3 && 0<=Re[z]<7.987982299275 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=10},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-1.1090884143613475,f'[0]==-0.8672474405325419*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (7.987982299275<=Re[z]<12.4311416939585 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=17},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-0.2526480375001583,f'[0]==0.11862078693056331*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (12.4311416939585<=Re[z]<21.84733876926896 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=26},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==0.03549886962148167,f'[0]==0.012683609989844821*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (21.84733876926896<=Re[z]<29.30235811735719 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=40},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-0.022696747596337125,f'[0]==-0.008814622364539303*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (29.30235811735719<=Re[z]<50.48293505082494 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=52},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-1.8441194967352004,f'[0]==-2.010053310058003*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (50.48293505082494<=Re[z]<53.839 && Abs[Im[z]]<=1 && Precision[z]<Infinity)

LaneEmden[2,z_]:=
  Module[{theta,sol,f,x,shift=65},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-0.04187417130248338,f'[0]==0.009077861959461834*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   f[Abs[z-shift]]/.sol[[1]]]/;
  ((Re[z]>=53.839 || 50.48293505082494<=Re[z]<53.839 && Abs[Im[z]]>1) && Precision[z]<Infinity)

(*********************  LaneEmdenPrime[2, z]  **********************)

LaneEmdenPrime[2.,z_]:=LaneEmdenPrime[2,z];

LaneEmdenPrime[2,z_]:=smallLaneEmdenPrime[2,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[2,z_]:=
  -LaneEmdenPrime[2,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=4},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==0.04884014997594444,f'[0]==-0.15040965958043956*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (Abs[z]>10^-3 && 0<=Re[z]<7.987982299275 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=10},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-1.1090884143613475,f'[0]==-0.8672474405325419*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (7.987982299275<=Re[z]<12.4311416939585 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=17},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-0.2526480375001583,f'[0]==0.11862078693056331*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (12.4311416939585<=Re[z]<21.84733876926896 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=26},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==0.03549886962148167,f'[0]==0.012683609989844821*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (21.84733876926896<=Re[z]<29.30235811735719 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=40},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-0.022696747596337125,f'[0]==-0.008814622364539303*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (29.30235811735719<=Re[z]<50.48293505082494 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=52},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-1.8441194967352004,f'[0]==-2.010053310058003*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (50.48293505082494<=Re[z]<53.839 && Abs[Im[z]]<=1 && Precision[z]<Infinity)

LaneEmdenPrime[2,z_]:=
  Module[{theta,sol,f,x,shift=65},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2==0,
     f[0]==-0.04187417130248338,f'[0]==0.009077861959461834*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  ((Re[z]>=53.839 || 50.48293505082494<=Re[z]<53.839 && Abs[Im[z]]>1) && Precision[z]<Infinity)

(************************  LaneEmden[3, z]  ************************)

LaneEmden[3.,z_]:=LaneEmden[3,z];

LaneEmden[3,z_]:=smallLaneEmden[3,z]/;(Abs[z]<=10^-3)

LaneEmden[3,z_]:=
  LaneEmden[3,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=5},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==0.11081983513962561,f'[0]==-0.08012604337165627*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (Abs[z]>10^-3 && 0<=Re[z]<10.062535336313266 && Precision[z]<Infinity)

LaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=12},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==-0.12103117453302031,f'[0]==-0.0114248524495963*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (10.062535336313266<=Re[z]<14.045533373642773 && Precision[z]<Infinity)

LaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=36},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==0.00018238724679557156,f'[0]==0.004787035481958655*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (14.045533373642773<=Re[z]<58.01682325157644 && Precision[z]<Infinity)

LaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=65},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==0.055915188857236335,f'[0]==-0.000813478649267057*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   f[Abs[z-shift]]/.sol[[1]]]/;
  (Re[z]>=58.01682325157644 && Precision[z]<Infinity)

(*********************  LaneEmdenPrime[3, z]  **********************)

LaneEmdenPrime[3.,z_]:=LaneEmdenPrime[3,z];

LaneEmdenPrime[3,z_]:=smallLaneEmdenPrime[3,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[3,z_]:=
  -LaneEmdenPrime[3,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=5},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==0.11081983513962561,f'[0]==-0.08012604337165627*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (Abs[z]>10^-3 && 0<=Re[z]<10.062535336313266 && Precision[z]<Infinity)

LaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=12},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==-0.12103117453302031,f'[0]==-0.0114248524495963*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (10.062535336313266<=Re[z]<14.045533373642773 && Precision[z]<Infinity)

LaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=36},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==0.00018238724679557156,f'[0]==0.004787035481958655*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (14.045533373642773<=Re[z]<58.01682325157644 && Precision[z]<Infinity)

LaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=65},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^3==0,
     f[0]==0.055915188857236335,f'[0]==-0.000813478649267057*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->15000];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (Re[z]>=58.01682325157644 && Precision[z]<Infinity)

(************************  LaneEmden[4, z]  ************************)

LaneEmden[4.,z_]:=LaneEmden[4,z];

LaneEmden[4,z_]:=smallLaneEmden[4,z]/;(Abs[z]<=10^-3)

LaneEmden[4,z_]:=
  LaneEmden[4,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[4,z_]:=
  Conjugate[LaneEmden[4,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmden[4,z_]:=
  If[Abs[Im[z]]>0 || Re[z]>97.788,ndsLaneEmden4[z],Re[ndsLaneEmden4[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsLaneEmden4[z_]:=
  Module[{theta,sol,f,x,shift=1+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4==0,
     f[0]==0.887660272684767-0.28561416370611725 I,
     f'[0]==(-0.39555144377923934-0.016013813800647245 I)*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->36000];
   f[Abs[z-shift]]/.sol[[1]]];

(*********************  LaneEmdenPrime[4, z]  **********************)

LaneEmdenPrime[4.,z_]:=LaneEmdenPrime[4,z];

LaneEmdenPrime[4,z_]:=smallLaneEmdenPrime[4,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[4,z_]:=
  -LaneEmdenPrime[4,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[4,z_]:=
  Conjugate[LaneEmdenPrime[4,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[4,z_]:=
  If[Abs[Im[z]]>0 || Re[z]>97.788,ndsLaneEmden4Prime[z],Re[ndsLaneEmden4Prime[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsLaneEmden4Prime[z_]:=
  Module[{theta,sol,f,x,shift=1+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
     {Exp[-2 I*theta]*f''[x]+2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4==0,
     f[0]==0.887660272684767-0.28561416370611725 I,
     f'[0]==(-0.39555144377923934-0.016013813800647245 I)*Exp[I*theta]},
     f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->36000];
   Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]];

(************  LaneEmden[5, z], LaneEmdenPrime[5, z]  **************)

LaneEmden[5.,z_]:=LaneEmden[5,z];

LaneEmden[5,z_]:=1/Sqrt[1+z^2/3];

LaneEmdenPrime[5.,z_]:=LaneEmdenPrime[5,z];

LaneEmdenPrime[5,z_]:=-z/(3+z^2)/Sqrt[1+z^2/3];

(************************  Other case of n  ************************)

LaneEmden[n_,z_]:=
  smallLaneEmden[n,z]/;
  (Precision[z]<Infinity && Abs[z]<=10^-3 && N[n-Floor[Re[n]]]===0. && 
   Not[MemberQ[N[{0,1,2,3,4,5}],N[n]]])

LaneEmden[n_,z_]:=
  Module[{epsilon=2/10},
    If[Abs[Im[z]]>0,
      If[Im[z]>0,
        compLaneEmden[n,z-epsilon*I,epsilon],
        compLaneEmden[n,z+epsilon*I,-epsilon]],
      Re[compLaneEmden[n,z-epsilon*I,epsilon]]]]/;
  (Precision[z]<Infinity && Abs[z]>10^-3 && N[n-Floor[Re[n]]]===0. && 
   Not[MemberQ[N[{0,1,2,3,4,5}],N[n]]])

LaneEmdenPrime[n_,z_]:=
  smallLaneEmdenPrime[n,z]/;
  (Precision[z]<Infinity && Abs[z]<=10^-3 && N[n-Floor[Re[n]]]===0. && 
   Not[MemberQ[N[{0,1,2,3,4,5}],N[n]]])

LaneEmdenPrime[n_,z_]:=
  Module[{epsilon=2/10},
    If[Abs[Im[z]]>0,
      If[Im[z]>0,
        compLaneEmdenPrime[n,z-epsilon*I,epsilon],
        compLaneEmdenPrime[n,z+epsilon*I,-epsilon]],
      Re[compLaneEmdenPrime[n,z-epsilon*I,epsilon]]]]/;
  (Precision[z]<Infinity && Abs[z]>10^-3 && N[n-Floor[Re[n]]]===0. && 
   Not[MemberQ[N[{0,1,2,3,4,5}],N[n]]])

realLaneEmden[n_,z_,eps_]:=
  Module[{init,sol,f,x},
    init=SetPrecision[initLaneEmden[n,eps*I],30];
    sol=NDSolve[{f''[x]+2/(x+eps*I)*f'[x]+f[x]^n==0,
        f[0]==init[[1]],f'[0]==init[[2]]},f,{x,z},
        AccuracyGoal->20,PrecisionGoal->20,WorkingPrecision->25,
        MaxSteps->Infinity,Method->"Extrapolation"];
    {f[z],f'[z]}/.sol[[1]]];

compLaneEmden[n_,z_,eps_]:=
  Module[{rez,init,sol,f,x},
    rez=SetPrecision[Re[z],30];
    init=realLaneEmden[n,rez,eps];
    sol=NDSolve[{f''[x]+2 I/(rez+x*I+eps*I)*f'[x]-f[x]^n==0,
        f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]},
        AccuracyGoal->16,PrecisionGoal->16,WorkingPrecision->20,
        MaxSteps->Infinity,Method->"Extrapolation"];
   f[Im[z]]/.sol[[1]]];

compLaneEmdenPrime[n_,z_,eps_]:=
  Module[{rez,init,sol,f,x},
    rez=SetPrecision[Re[z],30];
    init=realLaneEmden[n,rez,eps];
    sol=NDSolve[{f''[x]+2 I/(rez+x*I+eps*I)*f'[x]-f[x]^n==0,
        f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]},
        AccuracyGoal->16,PrecisionGoal->16,WorkingPrecision->20,
        MaxSteps->Infinity,Method->"Extrapolation"];
   -I*f'[Im[z]]/.sol[[1]]];

(******************** Initial values (case of n) ********************)

initLaneEmden[n_,eps_]:=
  initLaneEmden[n,eps]=
  {smallLaneEmden[n,eps],smallLaneEmdenPrime[n,eps]};

smallLaneEmden[n_,z_]:=
   {1,-1/6,n/120,(5 n-8 n^2)/15120,(n (70-183 n+122 n^2))/3265920,
    (3150 n-10805 n^2+12642 n^3-5032 n^4)/1796256000,
    (n (138600-574850 n+915935 n^2-663166 n^3+183616 n^4))/840647808000,
    1/1235752277760000 (21021000 n-101038350 n^2+199037015 n^3-200573786 n^4+
    103178392 n^5-21625216 n^6),
    (n (1891890000-10267435500 n+23780949500 n^2-30057075285 n^3+21827357636 n^4-
    8618115372 n^5+1442431856 n^6))/1008373858652160000,
    (675404730000 n-4066235428500 n^2+10740122081500 n^3-16120795594195 n^4+
    14830640277988 n^5-8348507232868 n^6+2657923739344 n^7-368552598784 n^8)/
    3103774736931348480000,
    (n (171102531600000-1128186384570000 n+3329284073314500 n^2-5740042719521900 n^3+
    6317195348852735 n^4-4538114873629364 n^5+2074925918891156 n^6-551199819782480 n^7+
    65035924972928 n^8))/6517926947555831808000000,
    (118574054398800000 n-847953056599110000 n^2+2754994980587692500 n^3-
    5335484162711174500 n^4+6782008348777403475 n^5-5860922969087284308 n^6+
    3438918097715059380 n^7-1319254687791147504 n^8+299840088682556928 n^9-
    30720693974199296 n^10)/36278781390095759843328000000,
    (n (27272032511724000000-209899877314257900000 n+742585473289204545000 n^2-
    1589853990586539282500 n^3+2279636465710370388750 n^4-2285217511971127632065 n^5+
    1620103707989338077938 n^6-801095938682391176900 n^7+264081052577164986584 n^8-
    52342890902954850528 n^9+4731477379473053696 n^10))/65301806502172367717990400000000,
    (292492548688239900000000 n-2407727679567791080500000 n^2+
    9195746633610796568925000 n^3-21506169347321296292427500 n^4+
    34202980463231934681573750 n^5-38808980460014339776733875 n^6+
    32027099679032760833711130 n^7-19202222891680485796622676 n^8+
    8187910947830833115448600 n^9-2362149376317369744815488 n^10+
    414501122965955020208256 n^11-33481640459237921334272 n^12)/
    5363498575249425250149423513600000000,
    (n (221124366808309364400000000-1936756075830467573682000000 n+
    7930437146223451050391200000 n^2-20072686581539870886571635000 n^3+
    34963066401809955172434807500 n^4-44122055622079409416110797250 n^5+
    41330472041821201294282970245 n^6-28928234842472726418895042014 n^7+
    15000125040494993324994175236 n^8-5613801514059618788961091752 n^9+
    1437932380191503174606526112 n^10-226115793622726549905863424 n^11+
    16493052255406256464719872 n^12))/30486125901717733121849323251302400000000,
    (416819431433663151894000000000 n-3867496385662821202601310000000 n^2+
    16882139089049914444708944000000 n^3-45903449802858218536073035725000 n^4+
    86715109626338968318764034727500 n^5-120116482898054972311149279358750 n^6+
    125427333921403106783547207888725 n^7-99884641080164944434032201437850 n^8+
    60608427892759138379434053870876 n^9-27650184721678502692443004191576 n^10+
    9209962355138176861003618044608 n^11-2119120371712187001452350381184 n^12+
    301623911790430754413857998848 n^13-20040967781752516066254979072 n^14)/
    425281456328962377049798059355668480000000000,
    (n (60299877747403269307332000000000-590488630715774331753111900000000 n+
    2734756681550376698969964210000000 n^2-7939818733849579829605159217250000 n^3+
    16140226785640945479298509920000000 n^4-24290989676923671495116783969845000 n^5+
    27894363393324419394420799749939000 n^6-24811232135188157297157773940651125 n^7+
    17163651844363730273481493495468360 n^8-9181660593318139295696649899943816 n^9+
    3735719133762786050015460390322816 n^10-1120054483015611022584355878830288 n^11+
    233741802284939391172520775951744 n^12-30366862875286239628550995042048 n^13+
    1851597211618954876356979423232 n^14))/
    449097217883384270164586750679585914880000000000,
    (507423471244398511221198780000000000 n-
    5227134871638749987042285460300000000 n^2+
    25581350143689038693604780280110000000 n^3-
    78902911583274617292615946670828250000 n^4+
    171502741794355307161425455719088400000 n^5-
    278163309313879605574639400189168825000 n^6+
    347598917807071683315155425606703193000 n^7-
    340566586695944878785580189417190395025 n^8+
    263586073853155307885928459940392956760 n^9-
    161031608392255446968026459587137294600 n^10+
    76960903278917028947600200769633653824 n^11-
    28235213581314715275378793906976748304 n^12+
    7691595366094197564167501932038847872 n^13-
    1467648281890909435599711725419108096 n^14+
    175276988044237696765732547882207232 n^15-
    9869982372276456985971256525324288 n^16)/
    27255710153342591356288769898744069174067200000000000}.Table[z^k,{k,0,34,2}];

 smallLaneEmdenPrime[n_,z_]:=
   {-(1/3),n/30,(5 n-8 n^2)/2520,(n (70-183 n+122 n^2))/408240,
    (3150 n-10805 n^2+12642 n^3-5032 n^4)/179625600,
    (n (138600-574850 n+915935 n^2-663166 n^3+183616 n^4))/70053984000,
    1/88268019840000 (21021000 n-101038350 n^2+199037015 n^3-200573786 n^4+
    103178392 n^5-21625216 n^6),
    1/63023366165760000 n (1891890000-10267435500 n+23780949500 n^2-30057075285 n^3+
    21827357636 n^4-8618115372 n^5+1442431856 n^6),(675404730000 n-4066235428500 n^2+
    10740122081500 n^3-16120795594195 n^4+14830640277988 n^5-8348507232868 n^6+
    2657923739344 n^7-368552598784 n^8)/172431929829519360000,
    (n (171102531600000-1128186384570000 n+3329284073314500 n^2-5740042719521900 n^3+
    6317195348852735 n^4-4538114873629364 n^5+2074925918891156 n^6-551199819782480 n^7+
    65035924972928 n^8))/325896347377791590400000,
    (118574054398800000 n-847953056599110000 n^2+2754994980587692500 n^3-
    5335484162711174500 n^4+6782008348777403475 n^5-5860922969087284308 n^6+
    3438918097715059380 n^7-1319254687791147504 n^8+299840088682556928 n^9-
    30720693974199296 n^10)/1649035517731625447424000000,
    (n (27272032511724000000-209899877314257900000 n+742585473289204545000 n^2-
    1589853990586539282500 n^3+2279636465710370388750 n^4-2285217511971127632065 n^5+
    1620103707989338077938 n^6-801095938682391176900 n^7+264081052577164986584 n^8-
    52342890902954850528 n^9+4731477379473053696 n^10))/2720908604257181988249600000000,
    (292492548688239900000000 n-2407727679567791080500000 n^2+
    9195746633610796568925000 n^3-21506169347321296292427500 n^4+
    34202980463231934681573750 n^5-38808980460014339776733875 n^6+
    32027099679032760833711130 n^7-19202222891680485796622676 n^8+
    8187910947830833115448600 n^9-2362149376317369744815488 n^10+
    414501122965955020208256 n^11-33481640459237921334272 n^12)/
    206288406740362509621131673600000000,
    (n (221124366808309364400000000-1936756075830467573682000000 n+
    7930437146223451050391200000 n^2-20072686581539870886571635000 n^3+
    34963066401809955172434807500 n^4-44122055622079409416110797250 n^5+
    41330472041821201294282970245 n^6-28928234842472726418895042014 n^7+
    15000125040494993324994175236 n^8-5613801514059618788961091752 n^9+
    1437932380191503174606526112 n^10-226115793622726549905863424 n^11+
    16493052255406256464719872 n^12))/1088790210775633325780332973260800000000,
    (416819431433663151894000000000 n-3867496385662821202601310000000 n^2+
    16882139089049914444708944000000 n^3-45903449802858218536073035725000 n^4+
    86715109626338968318764034727500 n^5-120116482898054972311149279358750 n^6+
    125427333921403106783547207888725 n^7-99884641080164944434032201437850 n^8+
    60608427892759138379434053870876 n^9-27650184721678502692443004191576 n^10+
    9209962355138176861003618044608 n^11-2119120371712187001452350381184 n^12+
    301623911790430754413857998848 n^13-20040967781752516066254979072 n^14)/
    14176048544298745901659935311855616000000000,
    (n (60299877747403269307332000000000-590488630715774331753111900000000 n+
    2734756681550376698969964210000000 n^2-7939818733849579829605159217250000 n^3+
    16140226785640945479298509920000000 n^4-24290989676923671495116783969845000 n^5+
    27894363393324419394420799749939000 n^6-24811232135188157297157773940651125 n^7+
    17163651844363730273481493495468360 n^8-9181660593318139295696649899943816 n^9+
    3735719133762786050015460390322816 n^10-1120054483015611022584355878830288 n^11+
    233741802284939391172520775951744 n^12-30366862875286239628550995042048 n^13+
    1851597211618954876356979423232 n^14))/
    14034288058855758442643335958737059840000000000,
    (507423471244398511221198780000000000 n-
    5227134871638749987042285460300000000 n^2+
    25581350143689038693604780280110000000 n^3-
    78902911583274617292615946670828250000 n^4+
    171502741794355307161425455719088400000 n^5-
    278163309313879605574639400189168825000 n^6+
    347598917807071683315155425606703193000 n^7-
    340566586695944878785580189417190395025 n^8+
    263586073853155307885928459940392956760 n^9-
    161031608392255446968026459587137294600 n^10+
    76960903278917028947600200769633653824 n^11-
    28235213581314715275378793906976748304 n^12+
    7691595366094197564167501932038847872 n^13-
    1467648281890909435599711725419108096 n^14+
    175276988044237696765732547882207232 n^15-
    9869982372276456985971256525324288 n^16)/
    801638533921840922243787349963060858060800000000000}.Table[z^k,{k,1,33,2}];



(**********************************************************************************)
(*                    LaneEmden[n/2,z], LaneEmdenPrime[n/2,z]                     *)
(**********************************************************************************)

(***********************  LaneEmden[1/2, z]  ***********************)

LaneEmden[0.5,z_]:=LaneEmden[1/2,z];

LaneEmden[1/2,z_]:=
  smallSqLaneEmden[1,z]^2/;(Abs[z]<=10^-3)

LaneEmden[1/2,z_]:=
  LaneEmden[1/2,-z]/;
  (Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[1/2,z_]:=
  Conjugate[LaneEmden[1/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmden[1/2,z_]:=
  Module[{val=ndsSqLaneEmden[1,z]^2},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<2.752721201156106,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmden[1,z_]:=
  Module[{theta,sol,f,x,shift=3+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+1/2==0,
      f[0]==0.43237223652084844-0.6591849932176889 I,
      f'[0]==(-0.3499882967849031-0.3409074747728204 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]];

(********************  LaneEmdenPrime[1/2, z]  *********************)

LaneEmdenPrime[0.5,z_]:=LaneEmdenPrime[1/2,z];

LaneEmdenPrime[1/2,z_]:=
  2*smallSqLaneEmden[1,z]*smallSqLaneEmdenPrime[1,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[1/2,z_]:=
  -LaneEmdenPrime[1/2,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[1/2,z_]:=
  Conjugate[LaneEmdenPrime[1/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[1/2,z_]:=
  Module[{val=2*ndsSqLaneEmden[1,z]*ndsSqLaneEmdenPrime[1,z]},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<2.752721201156106,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmdenPrime[1,z_]:=
  Module[{theta,sol,f,x,shift=3+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+1/2==0,
      f[0]==0.43237223652084844-0.6591849932176889 I,
      f'[0]==(-0.3499882967849031-0.3409074747728204 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]];

(***********************  LaneEmden[3/2, z]  ***********************)

LaneEmden[1.5,z_]:=LaneEmden[3/2,z];

LaneEmden[3/2,z_]:=
  smallSqLaneEmden[3,z]^2/;(Abs[z]<=10^-3)

LaneEmden[3/2,z_]:=
  LaneEmden[3/2,-z]/;
  (Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[3/2,z_]:=
  Conjugate[LaneEmden[3/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmden[3/2,z_]:=
  Module[{val=ndsSqLaneEmden[3,z]^2},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<3.653659319420499,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=3.81 +4.31 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.41713631761374637-0.9830319752767789 I,
      f'[0]==(-0.008116431926899757+0.5117576174729289 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (0<=Re[z]<5.3973014945393025 && 0<=Im[z]<6.396731151695462)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=2.83 +16.07 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.25777680944288384 +0.2079461231260236 I,
      f'[0]==(0.049882173532130196 -0.022564056487931937 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (0<=Re[z]<5.3973014945393025 && 6.396731151695462<=Im[z]<23.93)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=2.73 +31.89 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.1982937989703415 -0.17961581147662387 I,
      f'[0]==(0.051136049589426726 +0.022963317079271166 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (0<=Re[z]<5.3973014945393025 && Im[z]>=23.93)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=6.39 +22.5 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.043029826822705536-0.24799169673635238 I,
      f'[0]==(-0.026546870117835845+0.020486967886760535 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (5.3973014945393025<=Re[z]<7.4338847589639965)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=10.14 +6.29 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.5556444352832253 -0.1962650815484927 I,
      f'[0]==(-0.11204577133396626-0.1540719902264478 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (7.4338847589639965<=Re[z]<13.033509221568998 && 0<=Im[z]<12.131574200679768)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=9.94 +17.75 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.5355368428272932 +0.20054700877648338 I,
      f'[0]==(-0.1077964134578871+0.17582449868409156 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (7.4338847589639965<=Re[z]<13.033509221568998 && 
   12.131574200679768<=Im[z]<22.478879346749032)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=8.46 +27.74 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.10843501730194846-0.4638266564003966 I,
      f'[0]==(-0.054946424688634546+0.13194036148879168 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (7.4338847589639965<=Re[z]<9.65666620901386 && Im[z]>=22.478879346749032)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=11.23 +27.94 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.2272884137024545+0.4167948174100801 I,
      f'[0]==(0.00026359989784666886 +0.13948098036523673 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (9.65666620901386<=Re[z]<13.033509221568998 && Im[z]>=22.478879346749032)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=14.5+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.1318514365865321+0.3038603278476928 I,
      f'[0]==(-0.06302781663162069-0.006638031648363658 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (13.033509221568998<=Re[z]<15.893242781868917)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=20.82 +4.41 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.6230775225272216 +0.022548768404662484 I,
      f'[0]==(-0.00020055526098906426-0.2165570569883031 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<29.099292859591557 && 0<=Im[z]<10.12297650022953)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=23.22+13.07 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.2550177200647654+1.2932352042811908 I,
      f'[0]==(-0.6103713304920375-0.33732085350232327 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<29.099292859591557 && 
   10.12297650022953<=Im[z]<21.09051052798522)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=19.04 +25.96 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.47937893146061306 -0.4179895533228962 I,
      f'[0]==(-0.19902586084402482-0.09864335832928946 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<22.743230609537246 && 
   21.09051052798522<=Im[z]<31.236852780159435)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=19.34 +36.05 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.41108851235504407 +0.5338165423799525 I,
      f'[0]==(-0.2495470503232666+0.04991350873219577 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<22.743230609537246 && Im[z]>=31.236852780159435)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=25.76 +28.93 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.6747476136503251+0.1941257248985828 I,
      f'[0]==(-0.2368600762826053+0.10024818064230578 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (22.743230609537246<=Re[z]<29.099292859591557 && Im[z]>=21.09051052798522)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=29.52 +17.95 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.08891184269371505+0.005890240832402462 I,
      f'[0]==(-0.08054188609058142+0.04736231335000821 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (29.099292859591557<=Re[z]<30.149516043506516)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=33.67 +7.77 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.3368995074712226 -0.039666806161782524 I,
      f'[0]==(-0.01924699980885126-0.08200000733260794 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (30.149516043506516<=Re[z]<37.410031047410264 && 0<=Im[z]<15.491519587415617)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=32.59 +27.44 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.1649565581172111 -0.06045721734629307 I,
      f'[0]==(-0.020748742194318368+0.00478695445954035 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (30.149516043506516<=Re[z]<35.34732364925446 && Im[z]>=15.491519587415617)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=36.44 +27.54 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.03863679582222968 +0.10929857451748304 I,
      f'[0]==(0.021001841388248503 +0.04698762197014378 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (35.34732364925446<=Re[z]<37.410031047410264 && Im[z]>=15.491519587415617)

ndsSqLaneEmden[3,z_]:=
  Module[{theta,sol,f,x,shift=38.91 +7.67 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.1441390463110059+0.19751551385543362 I,
      f'[0]==(0.000554693539258374 +0.04922696669932874 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    f[Abs[z-shift]]/.sol[[1]]]/;
  (Re[z]>=37.410031047410264)

(********************  LaneEmdenPrime[3/2, z]  *********************)

LaneEmdenPrime[1.5,z_]:=LaneEmdenPrime[3/2,z];

LaneEmdenPrime[3/2,z_]:=
  2*smallSqLaneEmden[3,z]*smallSqLaneEmdenPrime[3,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[3/2,z_]:=
  -LaneEmdenPrime[3/2,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[3/2,z_]:=
  Conjugate[LaneEmdenPrime[3/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[3/2,z_]:=
  Module[{val=2*ndsSqLaneEmden[3,z]*ndsSqLaneEmdenPrime[3,z]},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<3.653659319420499,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=3.81 +4.31 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.41713631761374637-0.9830319752767789 I,
      f'[0]==(-0.008116431926899757+0.5117576174729289 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (0<=Re[z]<5.3973014945393025 && 0<=Im[z]<6.396731151695462)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=2.83 +16.07 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.25777680944288384 +0.2079461231260236 I,
      f'[0]==(0.049882173532130196 -0.022564056487931937 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (0<=Re[z]<5.3973014945393025 && 6.396731151695462<=Im[z]<23.93)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=2.73 +31.89 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.1982937989703415 -0.17961581147662387 I,
      f'[0]==(0.051136049589426726 +0.022963317079271166 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (0<=Re[z]<5.3973014945393025 && Im[z]>=23.93)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=6.39 +22.5 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.043029826822705536-0.24799169673635238 I,
      f'[0]==(-0.026546870117835845+0.020486967886760535 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (5.3973014945393025<=Re[z]<7.4338847589639965)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=10.14 +6.29 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.5556444352832253 -0.1962650815484927 I,
      f'[0]==(-0.11204577133396626-0.1540719902264478 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (7.4338847589639965<=Re[z]<13.033509221568998 && 0<=Im[z]<12.131574200679768)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=9.94 +17.75 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.5355368428272932 +0.20054700877648338 I,
      f'[0]==(-0.1077964134578871+0.17582449868409156 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (7.4338847589639965<=Re[z]<13.033509221568998 && 
   12.131574200679768<=Im[z]<22.478879346749032)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=8.46 +27.74 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.10843501730194846-0.4638266564003966 I,
      f'[0]==(-0.054946424688634546+0.13194036148879168 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (7.4338847589639965<=Re[z]<9.65666620901386 && Im[z]>=22.478879346749032)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=11.23 +27.94 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.2272884137024545+0.4167948174100801 I,
      f'[0]==(0.00026359989784666886 +0.13948098036523673 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (9.65666620901386<=Re[z]<13.033509221568998 && Im[z]>=22.478879346749032)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=14.5+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.1318514365865321+0.3038603278476928 I,
      f'[0]==(-0.06302781663162069-0.006638031648363658 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (13.033509221568998<=Re[z]<15.893242781868917)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=20.82 +4.41 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.6230775225272216 +0.022548768404662484 I,
      f'[0]==(-0.00020055526098906426-0.2165570569883031 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<29.099292859591557 && 0<=Im[z]<10.12297650022953)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=23.22+13.07 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.2550177200647654+1.2932352042811908 I,
      f'[0]==(-0.6103713304920375-0.33732085350232327 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<29.099292859591557 && 
   10.12297650022953<=Im[z]<21.09051052798522)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=19.04 +25.96 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.47937893146061306 -0.4179895533228962 I,
      f'[0]==(-0.19902586084402482-0.09864335832928946 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<22.743230609537246 && 
   21.09051052798522<=Im[z]<31.236852780159435)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=19.34 +36.05 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.41108851235504407 +0.5338165423799525 I,
      f'[0]==(-0.2495470503232666+0.04991350873219577 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (15.893242781868917<=Re[z]<22.743230609537246 && Im[z]>=31.236852780159435)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=25.76 +28.93 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.6747476136503251+0.1941257248985828 I,
      f'[0]==(-0.2368600762826053+0.10024818064230578 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (22.743230609537246<=Re[z]<29.099292859591557 && Im[z]>=21.09051052798522)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=29.52 +17.95 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.08891184269371505+0.005890240832402462 I,
      f'[0]==(-0.08054188609058142+0.04736231335000821 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (29.099292859591557<=Re[z]<30.149516043506516)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=33.67 +7.77 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.3368995074712226 -0.039666806161782524 I,
      f'[0]==(-0.01924699980885126-0.08200000733260794 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (30.149516043506516<=Re[z]<37.410031047410264 && 0<=Im[z]<15.491519587415617)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=32.59 +27.44 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.1649565581172111 -0.06045721734629307 I,
      f'[0]==(-0.020748742194318368+0.00478695445954035 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (30.149516043506516<=Re[z]<35.34732364925446 && Im[z]>=15.491519587415617)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=36.44 +27.54 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==0.03863679582222968 +0.10929857451748304 I,
      f'[0]==(0.021001841388248503 +0.04698762197014378 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (35.34732364925446<=Re[z]<37.410031047410264 && Im[z]>=15.491519587415617)

ndsSqLaneEmdenPrime[3,z_]:=
  Module[{theta,sol,f,x,shift=38.91 +7.67 I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^2/2==0,
      f[0]==-0.1441390463110059+0.19751551385543362 I,
      f'[0]==(0.000554693539258374 +0.04922696669932874 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->12000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (Re[z]>=37.410031047410264)

(***********************  LaneEmden[5/2, z]  ***********************)

LaneEmden[2.5,z_]:=LaneEmden[5/2,z];

LaneEmden[5/2,z_]:=
  smallSqLaneEmden[5,z]^2/;(Abs[z]<=10^-3)

LaneEmden[5/2,z_]:=
  LaneEmden[5/2,-z]/;
  (Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[5/2,z_]:=
  Conjugate[LaneEmden[5/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmden[5/2,z_]:=
  Module[{val=ndsSqLaneEmden[5,z]^2},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<5.35456875969374,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=0.33+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==1.0764379640389368-0.06409160636024681 I,
      f'[0]==(-0.08726782232409871-0.18474207054520972 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(0<=Re[z]<0.5767567420669808)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=1.8+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==0.7951929903796064-0.20265884412753468 I,
      f'[0]==(-0.226785171634508-0.01209542415186438 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(0.5767567420669808<=Re[z]<2.9969384414280382)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=5.5+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==0.15849358632293448-0.2205073443262953 I,
      f'[0]==(-0.10668298162454962-0.070911626324305 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(2.9969384414280382<=Re[z]<8.518288503892364)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=11+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.043943634757677444-0.48933241070861294 I,
      f'[0]==(-0.04474512668616609-0.023634485832862342 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(8.518288503892364<=Re[z]<14.132117968847211)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=18.3+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.3414458893810158-0.23772045162238983 I,
      f'[0]==(0.005043746163883839+0.04552413978540329 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(14.132117968847211<=Re[z]<22.718953819861508)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=25.7+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.25504681998296874-0.11857720146185367 I,
      f'[0]==(0.011950888654119016-0.002961016864579007 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(22.718953819861508<=Re[z]<28.841154771465348)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=29.6+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.20781766330566764-0.15036310301366165 I,
      f'[0]==(0.012480081102904512-0.01217234983809957 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(28.841154771465348<=Re[z]<30.657875848015117)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=39.8+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.08022185875411397-0.25024913727020104 I,
      f'[0]==(0.009658463668472332-0.0011464268505702645 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(30.657875848015117<=Re[z]<49.41440070234359)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=62.88+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.13347059683274717-0.04962935495376409 I,
      f'[0]==(-0.009848425455037849+0.00438613131242356 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(49.41440070234359<=Re[z]<76.75469246756626)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=78+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.2628401259807681-0.06303549621269026 I,
      f'[0]==(-0.011089353287567934-0.007010419884680175 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(76.75469246756626<=Re[z]<79.43718036782862)

ndsSqLaneEmden[5,z_]:=
  Module[{theta,sol,f,x,shift=82+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.31508442505990736-0.10779784196333264 I,
      f'[0]==(-0.01505357886708653-0.017024748146263015 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    f[Abs[z-shift]]/.sol[[1]]]/;(Re[z]>=79.43718036782862)

(********************  LaneEmdenPrime[5/2, z]  *********************)

LaneEmdenPrime[2.5,z_]:=LaneEmdenPrime[5/2,z];

LaneEmdenPrime[5/2,z_]:=
  2*smallSqLaneEmden[5,z]*smallSqLaneEmdenPrime[5,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[5/2,z_]:=
  -LaneEmdenPrime[5/2,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[5/2,z_]:=
  Conjugate[LaneEmdenPrime[5/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[5/2,z_]:=
  Module[{val=2*ndsSqLaneEmden[5,z]*ndsSqLaneEmdenPrime[5,z]},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<5.35456875969374,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=0.33+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==1.0764379640389368-0.06409160636024681 I,
      f'[0]==(-0.08726782232409871-0.18474207054520972 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;(0<=Re[z]<0.5767567420669808)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=1.8+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==0.7951929903796064-0.20265884412753468 I,
      f'[0]==(-0.226785171634508-0.01209542415186438 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (0.5767567420669808<=Re[z]<2.9969384414280382)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=5.5+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==0.15849358632293448-0.2205073443262953 I,
      f'[0]==(-0.10668298162454962-0.070911626324305 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (2.9969384414280382<=Re[z]<8.518288503892364)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=11+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.043943634757677444-0.48933241070861294 I,
      f'[0]==(-0.04474512668616609-0.023634485832862342 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (8.518288503892364<=Re[z]<14.132117968847211)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=18.3+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.3414458893810158-0.23772045162238983 I,
      f'[0]==(0.005043746163883839+0.04552413978540329 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (14.132117968847211<=Re[z]<22.718953819861508)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=25.7+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.25504681998296874-0.11857720146185367 I,
      f'[0]==(0.011950888654119016-0.002961016864579007 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (22.718953819861508<=Re[z]<28.841154771465348)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=29.6+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.20781766330566764-0.15036310301366165 I,
      f'[0]==(0.012480081102904512-0.01217234983809957 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (28.841154771465348<=Re[z]<30.657875848015117)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=39.8+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.08022185875411397-0.25024913727020104 I,
      f'[0]==(0.009658463668472332-0.0011464268505702645 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (30.657875848015117<=Re[z]<49.41440070234359)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=62.88+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.13347059683274717-0.04962935495376409 I,
      f'[0]==(-0.009848425455037849+0.00438613131242356 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (49.41440070234359<=Re[z]<76.75469246756626)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=78+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.2628401259807681-0.06303549621269026 I,
      f'[0]==(-0.011089353287567934-0.007010419884680175 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (76.75469246756626<=Re[z]<79.43718036782862)

ndsSqLaneEmdenPrime[5,z_]:=
  Module[{theta,sol,f,x,shift=82+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^4/2==0,
      f[0]==-0.31508442505990736-0.10779784196333264 I,
      f'[0]==(-0.01505357886708653-0.017024748146263015 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;(Re[z]>=79.43718036782862)

(***********************  LaneEmden[7/2, z]  ***********************)

LaneEmden[3.5,z_]:=LaneEmden[7/2,z];

LaneEmden[7/2,z_]:=
  smallSqLaneEmden[7,z]^2/;(Abs[z]<=10^-3)

LaneEmden[7/2,z_]:=
  LaneEmden[7/2,-z]/;
  (Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmden[7/2,z_]:=
  Conjugate[LaneEmden[7/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmden[7/2,z_]:=
  Module[{val=ndsSqLaneEmden[7,z]^2},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<9.532797167224532,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmden[7,z_]:=
  Module[{theta,sol,f,x,shift=4.2+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^6/2==0,
      f[0]==0.487445864999575-0.09933858679190966 I,
      f'[0]==(-0.09664683620830848+0.019880953383754375 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->19000];
    f[Abs[z-shift]]/.sol[[1]]]/;(0<=Re[z]<8.847896202790723)

ndsSqLaneEmden[7,z_]:=
  Module[{theta,sol,f,x,shift=36+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^6/2==0,
      f[0]==0.07964580967837012-0.3455473109694515 I,
      f'[0]==(0.006708851738737848+0.0036631204671612894 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->19000];
    f[Abs[z-shift]]/.sol[[1]]]/;(8.847896202790723<=Re[z]<63.73010458395185)

ndsSqLaneEmden[7,z_]:=
  Module[{theta,sol,f,x,shift=80+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^6/2==0,
      f[0]==0.16768878686084804-0.14113046134306206 I,
      f'[0]==(0.0007628013320765976+0.0017579417835913989 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->19000];
    f[Abs[z-shift]]/.sol[[1]]]/;(Re[z]>=63.73010458395185)

(********************  LaneEmdenPrime[7/2, z]  *********************)

LaneEmdenPrime[3.5,z_]:=LaneEmdenPrime[7/2,z];

LaneEmdenPrime[7/2,z_]:=
  2*smallSqLaneEmden[7,z]*smallSqLaneEmdenPrime[7,z]/;(Abs[z]<=10^-3)

LaneEmdenPrime[7/2,z_]:=
  -LaneEmdenPrime[7/2,-z]/;(Abs[z]>10^-3 && Re[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[7/2,z_]:=
  Conjugate[LaneEmdenPrime[7/2,Conjugate[z]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]<0 && Precision[z]<Infinity)

LaneEmdenPrime[7/2,z_]:=
  Module[{val=2*ndsSqLaneEmden[7,z]*ndsSqLaneEmdenPrime[7,z]},
    If[Abs[Im[z]]>0,val,
      If[Re[z]<9.532797167224532,Re[val],val]]]/;
  (Abs[z]>10^-3 && Re[z]>=0 && Im[z]>=0 && Precision[z]<Infinity)

ndsSqLaneEmdenPrime[7,z_]:=
  Module[{theta,sol,f,x,shift=4.2+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^6/2==0,
      f[0]==0.487445864999575-0.09933858679190966 I,
      f'[0]==(-0.09664683620830848+0.019880953383754375 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->19000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;(0<=Re[z]<8.847896202790723)

ndsSqLaneEmdenPrime[7,z_]:=
  Module[{theta,sol,f,x,shift=36+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^6/2==0,
      f[0]==0.07964580967837012-0.3455473109694515 I,
      f'[0]==(0.006708851738737848+0.0036631204671612894 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->19000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;
  (8.847896202790723<=Re[z]<63.73010458395185)

ndsSqLaneEmdenPrime[7,z_]:=
  Module[{theta,sol,f,x,shift=80+I},
    theta=If[z==shift,0,Arg[z-shift]];
    sol=NDSolve[
      {Exp[-2 I*theta]*f''[x]+Exp[-2 I*theta]*(f'[x])^2/f[x]+
       2/(Exp[I*theta]*x+shift)*Exp[-I*theta]*f'[x]+f[x]^6/2==0,
      f[0]==0.16768878686084804-0.14113046134306206 I,
      f'[0]==(0.0007628013320765976+0.0017579417835913989 I)*Exp[I*theta]},
      f,{x,Abs[z-shift]},MaxStepSize->0.01,MaxSteps->19000];
    Exp[-I*theta]*f'[Abs[z-shift]]/.sol[[1]]]/;(Re[z]>=63.73010458395185)

(***********************  Other case of n/2  ************************)

LaneEmden[n_,z_]:=
  smallSqLaneEmden[2n,z]^2/;
  (Precision[z]<Infinity && Abs[z]<=10^-3 && N[n-Floor[Re[n]]]===0.5 && 
   Not[MemberQ[N[{1/2,3/2,5/2,7/2}],N[n]]])

LaneEmden[n_,z_]:=
  Module[{epsilon=2/10,valUp,valDown},
    valUp=compSqLanEmd[2 n,z-epsilon*I,epsilon]^2;
    valDown=compSqLanEmd[2 n,z+epsilon*I,-epsilon]^2;
    If[Abs[Im[z]]>0,
      If[Im[z]>0,valUp,valDown],
      If[N[n]===N[9/2] && Abs[z]>31.83646,valUp,Re[valUp]]]]/;
  (Precision[z]<Infinity && Abs[z]>10^-3 && N[n-Floor[Re[n]]]===0.5 && 
   Not[MemberQ[N[{1/2,3/2,5/2,7/2}],N[n]]])

LaneEmdenPrime[n_,z_]:=
  2*smallSqLaneEmden[2n,z]*smallSqLaneEmdenPrime[2n,z]/;
  (Precision[z]<Infinity && Abs[z]<=10^-3 && N[n-Floor[Re[n]]]===0.5 && 
   Not[MemberQ[N[{1/2,3/2,5/2,7/2}],N[n]]])

LaneEmdenPrime[n_,z_]:=
  Module[{epsilon=2/10,valUp,valDown},
    valUp=2*compSqLanEmd[2 n,z-epsilon*I,epsilon]*
        compSqLanEmdPrime[2 n,z-epsilon*I,epsilon];
    valDown=2*compSqLanEmd[2 n,z+epsilon*I,-epsilon]*
        compSqLanEmdPrime[2 n,z+epsilon*I,-epsilon];
    If[Abs[Im[z]]>0,
      If[Im[z]>0,valUp,valDown],
      If[N[n]===N[9/2] && Abs[z]>31.83646,valUp,Re[valUp]]]]/;
  (Precision[z]<Infinity && Abs[z]>10^-3 && N[n-Floor[Re[n]]]===0.5 && 
   Not[MemberQ[N[{1/2,3/2,5/2,7/2}],N[n]]])

realSqLanEmd[n_,z_,eps_]:=
  Module[{init,sol,f,x},
    init=SetPrecision[initSqLaneEmden[n,eps*I],30];
    sol=NDSolve[
      {f''[x]+(f'[x])^2/f[x]+2/(x+eps*I)*f'[x]+f[x]^(n-1)/2==0,
      f[0]==init[[1]],f'[0]==init[[2]]},f,{x,z},
      AccuracyGoal->20,PrecisionGoal->20,WorkingPrecision->25,MaxSteps->Infinity,
      Method->"Extrapolation"];
    {f[z],f'[z]}/.sol[[1]]];

compSqLanEmd[n_,z_,eps_]:=
  Module[{rez,init,sol,f,x},
    rez=SetPrecision[Re[z],30];
    init=realSqLanEmd[n,rez,eps];
    sol=NDSolve[
      {f''[x]+(f'[x])^2/f[x]+2 I/(rez+x*I+eps*I)*f'[x]-f[x]^(n-1)/2==0,
      f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]},
      AccuracyGoal->16,PrecisionGoal->16,WorkingPrecision->20,MaxSteps->Infinity,
      Method->"Extrapolation",MaxStepSize->0.5];
    f[Im[z]]/.sol[[1]]];

compSqLanEmdPrime[n_,z_,eps_]:=
  Module[{rez,init,sol,f,x},
    rez=SetPrecision[Re[z],30];
    init=realSqLanEmd[n,rez,eps];
    sol=NDSolve[
      {f''[x]+(f'[x])^2/f[x]+2 I/(rez+x*I+eps*I)*f'[x]-f[x]^(n-1)/2==0,
      f[0]==init[[1]],f'[0]==I*init[[2]]},f,{x,Im[z]},
      AccuracyGoal->16,PrecisionGoal->16,WorkingPrecision->20,MaxSteps->Infinity,
      Method->"Extrapolation",MaxStepSize->0.5];
    -I*f'[Im[z]]/.sol[[1]]];

(******************* Initial values (case of n/2) *******************)

initSqLaneEmden[n_,eps_]:=
  initSqLaneEmden[n,eps]=
  {smallSqLaneEmden[n,eps],smallSqLaneEmdenPrime[n,eps]};

smallSqLaneEmden[n_,z_]:=
  {1,-1/12,(-5+6 n)/1440,(-35+62 n-32 n^2)/120960,
   (-7875+17740 n-15348 n^2+4880 n^3)/261273600,
   (-606375+1641700 n-1889460 n^2+1065296 n^3-241536 n^4)/172440576000,
   (-165540375+521777550 n-734312380 n^2+566725960 n^3-234996896 n^4+41129984 n^5)/
   376610217984000,
   (-9104720625+32705233750 n-53914640500 n^2+51646991720 n^3-29874915616 n^4+
   9747697920 n^5-1384013824 n^6)/158176291553280000,
   (-18109289323125+72984401469000 n-137293769221000 n^2+155252822899200 n^3-
   112781235405520 n^4+52011772413312 n^5-13945460449024 n^6+1661681498112 n^7)/
   2323293370334576640000,
   (-8601912428484375+38427753317625000 n-81033494338755000 n^2+
   104956447521089600 n^3-90655176922978160 n^4+52980476242859648 n^5-
   20269178030031104 n^6+4602838193371136 n^7-471747326443520 n^8)/
   7945663326544252108800000,
   (-11259903368886046875+55219064089755431250 n-128836718890184025000 n^2+
   187339753904021530000 n^3-186147313043211313200 n^4+130153340657351611680 n^5-
   63544609944274235904 n^6+20736850083265887744 n^7-4078121423587946496 n^8+
   366282329447530496 n^9)/73417929137268889485312000000,
   (-4920577772203202484375+26278720426956269868750 n-67160011303298537085000 n^2+
   108074225243570411238000 n^3-120857896730736702134000 n^4+
   97619550516594666963680 n^5-57316253334960760636928 n^6+
   24001714265068681746944 n^7-6820459369839219200000 n^8+
   1181617963182320254976 n^9-94373971888740237312 n^10)/
   222896832860748348477407232000000,
   (-33582943295286856955859375+194011706872057627865812500 n-
   538746669426746821393237500 n^2+949131702434834754619490000 n^3-
   1176130970171348358738810000 n^4+1072129036790150974352952000 n^5-
   729941915098449067828495680 n^6+369171450616811874470612736 n^7-
   135212852288276251122816000 n^8+33995085178561026581352448 n^9-
   5258892438600182246178816 n^10+377912561253271744806912 n^11)/
   10431571777883022708742658457600000000,
   (-20855007786373138169588671875+129586012691021168020676437500 n-
   388397564612150456091466237500 n^2+742795095845846990081446290000 n^3-
   1008188761377361321921175090000 n^4+1020175515192194783538095112000 n^5-
   786003314646158407754527977280 n^6+462482124453085001790532651776 n^7-
   205306913590513029536885308416 n^8+66769671037291821165401100288 n^9-
   15042143021522493607052836864 n^10+2100675126221653391548612608 n^11-
   137140799321038525785178112 n^12)/43937780328443291649224077423411200000000,
   (-529195822579218381053312548828125+3519329927898489705026065570781250 n-
   11321635024986594712053426964687500 n^2+23343922505966156454313494996525000 n^3-
   34394453593403330475771758221690000 n^4+38160924320580311186645161008780000 n^5-
   32699511596791213561989112197147200 n^6+21827854399973500300917656491893120 n^7-
   11305414804056136473064018214155776 n^8+4469632968531416171114715724339200 n^9-
   1306368209504210191745139791126528 n^10+266448691570553371742358494969856 n^11-
   33897288776817758948260741906432 n^12+2026666261144320794384777871360 n^13)/
   7492270301606150092025689682240077824000000000,
   (-147645634499601928313874201123046875+
   1046382966132001493434560124910156250 n-
   3595756097594971087229215124924062500 n^2+
   7947970346520571731351239624738625000 n^3-
   12620937980776073496211536073398750000 n^4+
   15208855384466075543750891839086460000 n^5-
   14308184959448924605428583159460920000 n^6+
   10642613254561997176172418799681865600 n^7-
   6267665765256940088711807102194787840 n^8+
   2898165946470511951176942599095732224 n^9-
   1032322668810137177796327795855089664 n^10+
   273842781279320528872205318718881792 n^11-
   51002440267447877120820377391988736 n^12+
   5955892065483585115107706663862272 n^13-
   328351216136233223229521577115648 n^14)/
   13935622760987439171167782808966544752640000000000,
   (-800682275891341257246139792690283203125+
   6024362550114290267113319899463906250000 n-
   22021985997435492822597361937230061250000 n^2+
   51931810041957106072472526872583654000000 n^3-
   88354653256028472430295727387469767500000 n^4+
   114770821001746796121532667510897236480000 n^5-
   117371711867525127929607219511640230240000 n^6+
   95984172984793149195900256047825062348800 n^7-
   63099416330888300864365250115952835646720 n^8+
   33242914565249142999931602943300225134592 n^9-
   13878514551609848562360933386847208382464 n^10+
   4496282786135529568183909418241833172992 n^11-
   1091415222796896552679863843675606155264 n^12+
   186965944889147756432776237347903635456 n^13-
   20171353892409712676830735777224720384 n^14+
   1031443336315608527603913529587924992 n^15)/
   500344599610493016001608073973134822798786560000000000,
   (-7818662424078947377008555075620615478515625+
   62244934855371919109918158660292300718750000 n-
   241163982254726798576861235500500765331250000 n^2+
   604231684249780800841390396912474701120000000 n^3-
   1096013133571541689629465382367509680625500000 n^4+
   1525264049689042966996196907182399907716800000 n^5-
   1682263476551264714326722574169579246771040000 n^6+
   1496963978204934712885924311663558271562752000 n^7-
   1083457745517647180734619221019094817488902400 n^8+
   638213950975157189306602311083328656760401920 n^9-
   304116536458812619110251731513644515256606720 n^10+
   115690960990813245916956195027491802253623296 n^11-
   34360188572486210370966383546407944165851136 n^12+
   7685140437989944934957082731843566995243008 n^13-
   1218405314303025638823582759382786636775424 n^14+
   122124814988609929943373370369051373600768 n^15-
   5821552482745588965293510408792872845312 n^16)/
   32152143970970281208263334833513643713050024345600000000000}.Table[z^k,{k,0,34,2}];

smallSqLaneEmdenPrime[n_,z_]:=
  {-1/6,(-5+6 n)/360,(-35+62 n-32 n^2)/20160,
   (-7875+17740 n-15348 n^2+4880 n^3)/32659200,
   (-606375+1641700 n-1889460 n^2+1065296 n^3-241536 n^4)/17244057600,
   (-165540375+521777550 n-734312380 n^2+566725960 n^3-234996896 n^4+
   41129984 n^5)/31384184832000,
   (-9104720625+32705233750 n-53914640500 n^2+51646991720 n^3-
   29874915616 n^4+9747697920 n^5-1384013824 n^6)/11298306539520000,
   (-18109289323125+72984401469000 n-137293769221000 n^2+155252822899200 n^3-
   112781235405520 n^4+52011772413312 n^5-13945460449024 n^6+1661681498112 n^7)/
   145205835645911040000,
   (-8601912428484375+38427753317625000 n-81033494338755000 n^2+
   104956447521089600 n^3-90655176922978160 n^4+52980476242859648 n^5-
   20269178030031104 n^6+4602838193371136 n^7-471747326443520 n^8)/
   441425740363569561600000,
   (-11259903368886046875+55219064089755431250 n-128836718890184025000 n^2+
   187339753904021530000 n^3-186147313043211313200 n^4+130153340657351611680 n^5-
   63544609944274235904 n^6+20736850083265887744 n^7-4078121423587946496 n^8+
   366282329447530496 n^9)/3670896456863444474265600000,
   (-4920577772203202484375+26278720426956269868750 n-
   67160011303298537085000 n^2+108074225243570411238000 n^3-
   120857896730736702134000 n^4+97619550516594666963680 n^5-
   57316253334960760636928 n^6+24001714265068681746944 n^7-
   6820459369839219200000 n^8+1181617963182320254976 n^9-
   94373971888740237312 n^10)/10131674220943106748973056000000,
   (-33582943295286856955859375+194011706872057627865812500 n-
   538746669426746821393237500 n^2+949131702434834754619490000 n^3-
   1176130970171348358738810000 n^4+1072129036790150974352952000 n^5-
   729941915098449067828495680 n^6+369171450616811874470612736 n^7-
   135212852288276251122816000 n^8+33995085178561026581352448 n^9-
   5258892438600182246178816 n^10+377912561253271744806912 n^11)/
   434648824078459279530944102400000000,
   (-20855007786373138169588671875+129586012691021168020676437500 n-
   388397564612150456091466237500 n^2+742795095845846990081446290000 n^3-
   1008188761377361321921175090000 n^4+1020175515192194783538095112000 n^5-
   786003314646158407754527977280 n^6+462482124453085001790532651776 n^7-
   205306913590513029536885308416 n^8+66769671037291821165401100288 n^9-
   15042143021522493607052836864 n^10+2100675126221653391548612608 n^11-
   137140799321038525785178112 n^12)/1689914628017049678816310670131200000000,
   (-529195822579218381053312548828125+3519329927898489705026065570781250 n-
   11321635024986594712053426964687500 n^2+23343922505966156454313494996525000 n^3-
   34394453593403330475771758221690000 n^4+38160924320580311186645161008780000 n^5-
   32699511596791213561989112197147200 n^6+21827854399973500300917656491893120 n^7-
   11305414804056136473064018214155776 n^8+4469632968531416171114715724339200 n^9-
   1306368209504210191745139791126528 n^10+266448691570553371742358494969856 n^11-
   33897288776817758948260741906432 n^12+2026666261144320794384777871360 n^13)/
   267581082200219646143774631508574208000000000,
   (-147645634499601928313874201123046875+
   1046382966132001493434560124910156250 n-
   3595756097594971087229215124924062500 n^2+
   7947970346520571731351239624738625000 n^3-
   12620937980776073496211536073398750000 n^4+
   15208855384466075543750891839086460000 n^5-
   14308184959448924605428583159460920000 n^6+
   10642613254561997176172418799681865600 n^7-
   6267665765256940088711807102194787840 n^8+
   2898165946470511951176942599095732224 n^9-
   1032322668810137177796327795855089664 n^10+
   273842781279320528872205318718881792 n^11-
   51002440267447877120820377391988736 n^12+
   5955892065483585115107706663862272 n^13-
   328351216136233223229521577115648 n^14)/
   464520758699581305705592760298884825088000000000,
   (-800682275891341257246139792690283203125+
   6024362550114290267113319899463906250000 n-
   22021985997435492822597361937230061250000 n^2+
   51931810041957106072472526872583654000000 n^3-
   88354653256028472430295727387469767500000 n^4+
   114770821001746796121532667510897236480000 n^5-
   117371711867525127929607219511640230240000 n^6+
   95984172984793149195900256047825062348800 n^7-
   63099416330888300864365250115952835646720 n^8+
   33242914565249142999931602943300225134592 n^9-
   13878514551609848562360933386847208382464 n^10+
   4496282786135529568183909418241833172992 n^11-
   1091415222796896552679863843675606155264 n^12+
   186965944889147756432776237347903635456 n^13-
   20171353892409712676830735777224720384 n^14+
   1031443336315608527603913529587924992 n^15)/
   15635768737827906750050252311660463212462080000000000,
   (-7818662424078947377008555075620615478515625+
   62244934855371919109918158660292300718750000 n-
   241163982254726798576861235500500765331250000 n^2+
   604231684249780800841390396912474701120000000 n^3-
   1096013133571541689629465382367509680625500000 n^4+
   1525264049689042966996196907182399907716800000 n^5-
   1682263476551264714326722574169579246771040000 n^6+
   1496963978204934712885924311663558271562752000 n^7-
   1083457745517647180734619221019094817488902400 n^8+
   638213950975157189306602311083328656760401920 n^9-
   304116536458812619110251731513644515256606720 n^10+
   115690960990813245916956195027491802253623296 n^11-
   34360188572486210370966383546407944165851136 n^12+
   7685140437989944934957082731843566995243008 n^13-
   1218405314303025638823582759382786636775424 n^14+
   122124814988609929943373370369051373600768 n^15-
   5821552482745588965293510408792872845312 n^16)/
   945651293263831800243039259809224815089706598400000000000}.Table[z^k,{k,1,33,2}];



(**********************************************************************************)
(*                           LorenzX, LorenzY, LorenzZ                            *)
(**********************************************************************************)

LorenzX[sig_,bet_,rho_,{t_,tMax_},{x0_,y0_,z0_}]:=
  Module[{init,sol,x,y,z,u},
    init=realLorenzXYZ[sig,bet,rho,{Re[t],tMax},{x0,y0,z0}];
    If[Abs[Im[t]]>0,
      sol=NDSolve[{x'[u]==sig*I*(y[u]-x[u]),y'[u]==I*x[u]*(rho-z[u])-I*y[u],
        z'[u]==I*x[u]*y[u]-bet*I*z[u],
        x[0]==init[[1]],y[0]==init[[2]],z[0]==init[[3]]},{x,y,z},{u,Im[t]},
        MaxSteps->Infinity];
      x[Im[t]]/.sol[[1]],
      init[[1]]]]/;
  (Precision[t]<Infinity)

LorenzY[sig_,bet_,rho_,{t_,tMax_},{x0_,y0_,z0_}]:=
  Module[{init,sol,x,y,z,u},
    init=realLorenzXYZ[sig,bet,rho,{Re[t],tMax},{x0,y0,z0}];
    If[Abs[Im[t]]>0,
      sol=NDSolve[{x'[u]==sig*I*(y[u]-x[u]),y'[u]==I*x[u]*(rho-z[u])-I*y[u],
        z'[u]==I*x[u]*y[u]-bet*I*z[u],
        x[0]==init[[1]],y[0]==init[[2]],z[0]==init[[3]]},{x,y,z},{u,Im[t]},
        MaxSteps->Infinity];
      y[Im[t]]/.sol[[1]],
      init[[2]]]]/;
  (Precision[t]<Infinity)

LorenzZ[sig_,bet_,rho_,{t_,tMax_},{x0_,y0_,z0_}]:=
  Module[{init,sol,x,y,z,u},
    init=realLorenzXYZ[sig,bet,rho,{Re[t],tMax},{x0,y0,z0}];
    If[Abs[Im[t]]>0,
      sol=NDSolve[{x'[u]==sig*I*(y[u]-x[u]),y'[u]==I*x[u]*(rho-z[u])-I*y[u],
        z'[u]==I*x[u]*y[u]-bet*I*z[u],
        x[0]==init[[1]],y[0]==init[[2]],z[0]==init[[3]]},{x,y,z},{u,Im[t]},
        MaxSteps->Infinity];
      z[Im[t]]/.sol[[1]],
      init[[3]]]]/;
  (Precision[t]<Infinity)

realLorenzXYZ[sig_,bet_,rho_,{t_,tMax_},{x0_,y0_,z0_}]:=
  Module[{sol,x,y,z,u},
    sol=NDSolve[{x'[u]==sig*(y[u]-x[u]),y'[u]==x[u]*(rho-z[u])-y[u],
      z'[u]==x[u]*y[u]-bet*z[u],x[0]==x0,y[0]==y0,z[0]==z0},{x,y,z},{u,0,tMax},
      MaxSteps->Infinity];
    {x[t],y[t],z[t]}/.sol[[1]]];



(**********************************************************************************)

End[]

Protect[VanDerPol, VanDerPolPrime, VanDerPolPhase, Duffing, DuffingPrime, 
        DuffingPhase, NonForcedDuffing, NonForcedDuffingPrime, 
        NonForcedDuffingPhase, DuffingVanDerPol, DuffingVanDerPolPrime, 
        DuffingVanDerPolPhase, LotkaVolterraX, LotkaVolterraY, 
        Blasius, BlasiusPrime, BlasiusPrimePrime, 
        Polking, PolkingPrime, PolkingPhase, BrusselatorX, BrusselatorY, 
        NLDampedOscillation, NLDampedOscillationPrime, 
        NLDampedOscillationPhase, Elastica, 
        HyperLemniscateS, HyperLemniscateSPrime, HyperOmega, PerHLOddGreater3, 
        HyperLemniscateSRadialCut, HyperLemniscateSPrimeRadialCut, 
        HyperLemniscateS6, HyperLemniscateS8, 
        SquigonometricC, SquigonometricS, 
        SquigonometricCAnalytic, SquigonometricSAnalytic, 
        LaneEmden, LaneEmdenPrime, 
        LorenzX, LorenzY, LorenzZ]

EndPackage[]
